m4_divert(-1)m4_dnl
# automake.m4 --
# 
# Part of: DevelStuff
# Contents: automake M4 macros
# Date: Sat Jan  4, 2003
# 
# Abstract
# 
#	This file declares a set of macros used to build a Makefile.in
#	project Makefile template.
#
#	All the variable declared in the macros are prefixed with "ds_"
#	with the exception of the ones declared in the following
#	modules: PACKAGE, DIRECTORIES and the program selection modules.
#
# Copyright (c)  2003, 2004  Marco Maggi
# 
# This file  is free software you  can redistribute it  and/or modify it
# under the terms of the GNU  General Public License as published by the
# Free Software  Foundation; either version  2, or (at your  option) any
# later version.
# 
# This  file is  distributed in  the hope  that it  will be  useful, but
# WITHOUT   ANY  WARRANTY;   without  even   the  implied   warranty  of
# MERCHANTABILITY  or FITNESS  FOR A  PARTICULAR PURPOSE.   See  the GNU
# General Public License for more details.
# 
# You  should have received  a copy  of the  GNU General  Public License
# along with this file; see the file COPYING.  If not, write to the Free
# Software Foundation,  Inc., 59  Temple Place -  Suite 330,  Boston, MA
# 02111-1307, USA.
# 

#PAGE
## ------------------------------------------------------------
## Setup and macros.
## ------------------------------------------------------------

m4_changequote([,])

m4_define([DS_MSG_ERROR],
[m4_errprint(automake.sh *** error:m4___file__:m4___line__: $1
)])

m4_define([DS_MSG_WARN],
[m4_errprint(automake.sh *** warning:m4___file__:m4___line__: $1
)])

m4_define([DS_MSG_STRING],
[m4_ifdef([DS_OPTION_VERBOSE], [m4_errprint(automake.sh:m4___file__: $1
)])])

m4_define([DS_MSG_DEBUG],
[m4_ifdef([DS_OPTION_DEBUG], [m4_errprint(automake.sh:m4___file__: $1
)])])

m4_define([DS_DEFUN], [m4_define([$1], [m4_define([$1_INVOKED])$2])])

m4_define([DS_REQUIRE],
[m4_ifdef($1_INVOKED, [DS_MSG_ERROR(prerequisite violation: $1)])])

m4_define([DS_INCLUDE], [m4_include([$1])])

#PAGE
DS_DEFUN([DS_PACKAGE_VARIABLES], [#PAGE
## ------------------------------------------------------------
## Package variables.
## ------------------------------------------------------------

PACKAGE_NAME		= @PACKAGE_NAME@
PACKAGE_VERSION		= @PACKAGE_VERSION@
PACKAGE_XVERSION	= @PACKAGE_XVERSION@
PKG_DIR			= $(PACKAGE_NAME)_$(PACKAGE_VERSION)
])
#PAGE
DS_DEFUN([DS_DIRECTORIES], [#PAGE
## ------------------------------------------------------------
## Directory variables.
## ------------------------------------------------------------

CONFIGDIR	= @CONFIGDIR@
INSTALL_ROOT	=

# If there is not a value for "TMPDIR" from the environment
# we select a common default.
TMPDIR		?= /tmp

top_builddir	= @top_builddir@
ifeq	(,$(top_builddir))
top_builddir	= .
endif

builddir	= @builddir@
ifeq	(,$(builddir))
builddir	= .
endif

top_srcdir	= @top_srcdir@
srcdir		= @srcdir@

prefix		= @prefix@
exec_prefix	= @exec_prefix@

bindir		= @bindir@
datadir		= @datadir@
docdir		= $(prefix)/doc
includedir	= @includedir@
infodir		= @infodir@
libdir		= @libdir@
libexecdir	= @libexecdir@
localstatedir	= @localstatedir@
mandir		= @mandir@
sbindir		= @sbindir@
sharedstatedir	= @sharedstatedir@
sysconfdir	= @sysconfdir@

pkgdatadir	= $(datadir)/$(PKG_DIR)
pkgdocdir	= $(docdir)/$(PKG_DIR)
pkgexampledir	= $(pkgdocdir)/examples
pkghtmldir	= $(pkgdocdir)/HTML
pkgincludedir	= $(includedir)/$(PKG_DIR)
pkglibdir	= $(libdir)/$(PKG_DIR)
pkglibexecdir	= $(libexecdir)/$(PKG_DIR)
pkgsysconfdir	= $(sysconfdir)/$(PKG_DIR)
])
#PAGE
DS_DEFUN([DS_COMMON_PROGRAMS], [#PAGE
## ------------------------------------------------------------
## Common programs.
## ------------------------------------------------------------

BASH			= @BASH@
SHELL			= @SHELL@
@SET_MAKE@

RM			= @RM@
MKDIR			= @MKDIR@
SYMLINK			= @SYMLINK@
M4			= @M4@

SED			= @SED@
GREP			= @GREP@

GDB			= @GDB@

INSTALL_DIR_MODE	= 0755
INSTALL_BIN_MODE	= 0555
INSTALL_DATA_MODE	= 0444

INSTALL			= @INSTALL@
INSTALL_DIR		= $(INSTALL) -m $(INSTALL_DIR_MODE) -d
INSTALL_BIN		= $(INSTALL) -m $(INSTALL_BIN_MODE)
INSTALL_DATA		= $(INSTALL) -m $(INSTALL_DATA_MODE)
])
#PAGE
DS_DEFUN([DS_MAIN_RULES], [#PAGE
## ------------------------------------------------------------
## Main rules.
## ------------------------------------------------------------

.PHONY: all clean realclean install

all:		bin dev doc sta
clean:		bin-clean dev-clean doc-clean sta-clean
realclean:	bin-realclean dev-realclean doc-realclean sta-realclean
install:	bin-install dev-install doc-install sta-install

.PHONY: bin bin-clean bin-realclean bin-install
.PHONY: dev dev-clean dev-realclean dev-install
.PHONY: sta sta-clean sta-realclean sta-install
.PHONY: doc doc-clean doc-realclean doc-install
])
#PAGE
DS_DEFUN([DS_AUTO_CONFIGURATION], [#PAGE
## ------------------------------------------------------------
## Auto configuration rules.
## ------------------------------------------------------------

config_CLEANFILES	= config.log config.status config.cache Makefile

.PHONY: config-clean

Makefile: $(srcdir)/Makefile.in $(srcdir)/configure $(builddir)/config.status
	CONFIG_FILES=Makefile CONFIG_HEADERS= $(builddir)/config.status

config.status: $(srcdir)/configure
	$(builddir)/config.status --recheck

config-clean:
	-$(RM) $(config_CLEANFILES)
])
#PAGE
DS_DEFUN([DS_TCL_TESTS], [#PAGE
## ------------------------------------------------------------
## TCL test rules.
## ------------------------------------------------------------

TCLSH			= @TCLSH@
TCLTESTMAIN		= DS_TCLTESTMAIN_MACRO

#test_TARGETS		=
#test_CLEANFILES	=
#test_REALCLEANFILES	=

.PHONY: test tests test-clean tests-clean test-realclean tests-realclean

test tests:
	if test -f $(TCLTESTMAIN); then \
	  export TMPDIR=$(TMPDIR);			\
	  export top_srcdir=$(top_srcdir);		\
	  export srcdir=$(top_srcdir);			\
	  export top_builddir=$(top_builddir);		\
	  export builddir=$(builddir);			\
	  $(TCLSH) $(TCLTESTMAIN) $(TESTFLAGS); \
	fi

test tests: $(test_TARGETS)
test-clean tests-clean:
	-$(RM) $(test_CLEANFILES)
test-realclean tests-realclean:
	-$(RM) $(test_CLEANFILES) $(test_REALCLEANFILES)

clean: test-clean
realclean: test-realclean
])
#PAGE
DS_DEFUN([DS_TESTS], [#PAGE
## ------------------------------------------------------------
## Test rules.
## ------------------------------------------------------------

test_SRCDIR		= DS_TEST_SRCDIR_MACRO
#test_TARGETS		=

#test_CLEANFILES	=
#test_REALCLEANFILES	=

.PHONY: test tests test-clean tests-clean test-realclean tests-realclean

test tests: $(test_TARGETS)
test-clean tests-clean:
	-$(RM) $(test_CLEANFILES)
test-realclean tests-realclean:
	-$(RM) $(test_CLEANFILES) $(test_REALCLEANFILES)

aux-clean:	test-clean
aux-realclean:	test-realclean
])
#PAGE
DS_DEFUN([DS_EXAMPLES], [#PAGE
## ------------------------------------------------------------
## Examples rules.
## ------------------------------------------------------------

example_SRCDIR		= DS_EXAMPLE_SRCDIR_MACRO
#example_INSTLST	=
example_INSTDIR		= $(pkgexampledir)

#example_CLEANFILES	=
#example_REALCLEANFILES	=

.PHONY: example-all example-clean example-realclean example-install

example-all: $(example_TARGETS)
example-clean:
	-$(RM) $(example_CLEANFILES)
example-realclean:
	-$(RM) $(example_CLEANFILES) $(example_REALCLEANFILES)

example-install:
DS_INSTALL_DATA(example)

clean:		example-clean
realclean:	example-realclean
])
#PAGE
DS_DEFUN([DS_GENERIC_DOCUMENTATION], [#PAGE
## ------------------------------------------------------------
## Generic package documentation.
## ------------------------------------------------------------

# doc_generic_TARGETS		= 
# doc_generic_CLEANFILES	=
# doc_generic_REALCLEANFILES	=

doc_generic_INSTLST		?= $(wildcard $(addprefix $(top_srcdir)/, \
				  README* COPYING license.terms INSTALL BUGS \
				  NEWS ChangeLog)) \
				  $(wildcard $(builddir)/meta/DESCRIPTION.txt)
doc_generic_INSTDIR		= $(pkgdocdir)

.PHONY: doc-generic-all doc-generic-clean doc-generic-realclean
.PHONY: doc-generic-install

doc-generic-all: $(doc_generic_TARGETS)
doc-generic-clean:
	-$(RM) $(doc_generic_CLEANFILES)
doc-generic-realclean:
	-$(RM) $(doc_generic_REALCLEANFILES)

doc-generic-install:
DS_INSTALL_DATA(doc_generic)


doc:		doc-generic-all
doc-clean:	doc-generic-clean
doc-realclean:	doc-generic-realclean
doc-install:	doc-generic-install
])
#PAGE
DS_DEFUN([DS_TEXINFO_DOCUMENTATION], [#PAGE
## ------------------------------------------------------------
## Package documentation in Texinfo format.
## ------------------------------------------------------------

doc_texinfo_SRCDIR	= DS_DOC_SRCDIR_MACRO
doc_texinfo_SOURCES	= $(wildcard $(doc_texinfo_SRCDIR)/*.texi)

vpath	%.texi		$(doc_texinfo_SRCDIR)
vpath	%.texiinc	$(doc_texinfo_SRCDIR)

doc_texi2html_TARGETS	= $(notdir $(doc_texinfo_SOURCES:.texi=.html))
doc_texi2html_INSTLST	= $(wildcard $(doc_texi2html_TARGETS))
doc_texi2html_INSTDIR	= $(pkghtmldir)

doc_texi2info_TARGETS	= $(notdir $(doc_texinfo_SOURCES:.texi=.info))
doc_texi2info_INSTLST	= $(wildcard $(foreach f, $(doc_texi2info_TARGETS), $(f)*))
doc_texi2info_INSTDIR	= $(infodir)

doc_texinfo_CLEANFILES	 = $(doc_texi2info_INSTLST) $(doc_texi2html_INSTLST)
doc_texinfo_REALCLEANFILES = $(doc_texinfo_CLEANFILES) version.texiinc

MAKEINFO		= @MAKEINFO@
DS_TEXI2INFO_FLAGS	= -I $(doc_texinfo_SRCDIR) -I $(builddir)
DS_TEXI2HTML_FLAGS	= -I $(doc_texinfo_SRCDIR) -I $(builddir) --html --no-split

.PHONY: doc-texinfo-all doc-texinfo-clean doc-texinfo-realclean
.PHONY: doc-texinfo-install

doc-texinfo-all: $(doc_texi2info_TARGETS) $(doc_texi2html_TARGETS)
doc-texinfo-clean:
	-$(RM) $(doc_texinfo_CLEANFILES)
doc-texinfo-realclean:
	-$(RM) $(doc_texinfo_REALCLEANFILES)

doc-texinfo-install:
	@echo "Installing documentation in Info format."
DS_INSTALL_DATA([doc_texi2info])
	@echo "Installing documentation in HTML format."
DS_INSTALL_DATA([doc_texi2html])

$(doc_texi2info_TARGETS): %.info : %.texi version.texiinc
	$(MAKEINFO) $(DS_TEXI2INFO_FLAGS) $(<) -o $(@)

$(doc_texi2html_TARGETS): %.html : %.texi version.texiinc
	$(MAKEINFO) $(DS_TEXI2HTML_FLAGS) $(<) -o $(@)

version.texiinc: Makefile
	echo -e "@macro version{}\n$(PACKAGE_VERSION)\n@end macro\n" >$(@)

doc:		doc-texinfo-all
doc-clean:	doc-texinfo-clean
doc-realclean:	doc-texinfo-realclean
doc-install:	doc-texinfo-install
])
#PAGE
DS_DEFUN([DS_C_COMPILER_RULES], [#PAGE
## ------------------------------------------------------------
## C compiler rules.
## ------------------------------------------------------------

ALL_CFLAGS	= @ALL_CFLAGS@ $(CPPFLAGS) $(INCLUDES) $(DEFS)
CFLAGS		= @CFLAGS@

INCLUDES	= @INCLUDES@ -I DS_GENERIC_SRCDIR_MACRO -I DS_TEST_SRCDIR_MACRO
DEFS		= @DEFS@
LIBS		= @LIBS@
CPPFLAGS	= @CPPFLAGS@

CC		= @CC@
AR		= @AR@ rc
RANLIB		= @RANLIB@
STRIP		= @STRIP@

%.o: %.c
	$(CC) $(ALL_CFLAGS) $(CFLAGS) $(<) -c -o $(@)

])
#PAGE
DS_DEFUN([DS_C_SHARED_LIBRARY], [#PAGE
## ------------------------------------------------------------
## Shared library rules.
## ------------------------------------------------------------

library_shared_OBJS		?= $(library_OBJS)
library_shared_NAME		?= lib$(PACKAGE_NAME)$(PACKAGE_VERSION).so

LDFLAGS				= @LDFLAGS@
library_shared_FLAGS		= -fPIC -shared $(LDFLAGS)

library_shared_INSTLST		= $(library_shared_NAME)
library_shared_INSTDIR		= $(libdir)

library_shared_CLEANFILES	= $(library_shared_NAME) $(library_shared_OBJS)
library_shared_REALCLEANFILES	= $(library_shared_CLEANFILES)

.PHONY: library-shared-all library-shared-clean library-shared-realclean
.PHONY: library-shared-install

library-shared-all: $(library_shared_NAME)
library-shared-clean:
	-$(RM) $(library_shared_CLEANFILES)
library-shared-realclean:
	-$(RM) $(library_shared_REALCLEANFILES)

library-shared-install:
DS_INSTALL_DATA(library_shared)


$(library_shared_NAME): $(library_shared_OBJS)
	$(CC) -o $(@) $(library_shared_FLAGS) $(library_shared_OBJS)


bin:		library-shared-all
bin-clean:	library-shared-clean
bin-realclean:	library-shared-realclean
bin-install:	library-shared-install
])
#PAGE
DS_DEFUN([DS_C_STATIC_LIBRARY], [#PAGE
## ------------------------------------------------------------
## Static library rules.
## ------------------------------------------------------------

library_static_OBJS		?= $(library_OBJS)
library_static_NAME		?= lib$(PACKAGE_NAME)$(PACKAGE_VERSION).a

library_static_INSTLST		= $(library_static_NAME)
library_static_INSTDIR		= $(libdir)

library_static_CLEANFILES	= $(library_static_NAME) $(library_static_OBJS)
library_static_REALCLEANFILES	= $(library_static_CLEANFILES)

.PHONY: library-static-all library-static-clean library-static-realclean
.PHONY: library-static-install

library-static-all: $(library_static_NAME)
library-static-clean:
	-$(RM) $(library_static_CLEANFILES)
library-static-realclean:
	-$(RM) $(library_static_REALCLEANFILES)
library-static-install:
DS_INSTALL_DATA(library_static)


$(library_static_NAME): $(library_static_OBJS)
	$(AR) $(@) $(library_static_OBJS)
	-($(RANLIB) $(@) || true) >/dev/null 2>&1


sta:		library-static-all
sta-clean:	library-static-clean
sta-realclean:	library-static-realclean
sta-install:	library-static-install
])
#PAGE
DS_DEFUN([DS_C_HEADERS_RULES], [#PAGE
## ------------------------------------------------------------
## Public headers rules.
## ------------------------------------------------------------

#headers_INSTLST	=
headers_INSTDIR		= $(pkgincludedir)

.PHONY: headers-install

headers-install:
DS_INSTALL_DATA([headers])

dev-install: headers-install
])
#PAGE
DS_DEFUN([DS_SHELL_SCRIPTS_RULES], [#PAGE
## ------------------------------------------------------------
## Shell scripts rules.
## ------------------------------------------------------------

M4		= @M4@
M4FLAGS		+= --prefix-builtins

%.sh: %.sh.m4
	$(M4) $(M4FLAGS) $(<) | \
	$(GREP) --invert-match -e '^#' -e '^$$' | \
	$(SED) -e "s/^ \\+//" >$(@)

])
#PAGE
DS_DEFUN([DS_TCL_SHELL_SCRIPTS_RULES], [#PAGE
## ------------------------------------------------------------
## TCL shell scripts rules.
## ------------------------------------------------------------

TCLPP		?= @TCLPP@

%.tcl: %.ptcl
	$(TCLPP) $(TCLPPFLAGS) $(<) --output=$(@)

])
#PAGE
DS_DEFUN([DS_END_OF_MAKEFILE], [#PAGE
## ------------------------------------------------------------
## Distribution targets.
## ------------------------------------------------------------

.PHONY: dist bindist bindist-bin bindist-dev bindist-doc bindist-sta

dist bindist bindist-bin bindist-dev bindist-doc bindist-sta:
	$(CONFIGDIR)/do.sh --$(@) --verbose

.PHONY: debian

debian debian-bin debian-doc debian-dev debian-sta:
	$(CONFIGDIR)/do.sh --$(@) --verbose


[]#PAGE
## ------------------------------------------------------------
## End of makefile.
## ------------------------------------------------------------

.PHONY: echo-variable
echo-variable:
	@echo $($(VARIABLE))

.NOEXPORT:

])
#PAGE
# DS_INSTALL_DIR --
#
#	Substitute the command used to install a directory, prefixing the
#	install directory with the value of "INSTALL_ROOT". This is useful
#	to build a temporary installation tree and use it to build packages
#	and distribution archives.
#
#  Arguments:
#
#	$* -	the list of directories to install
#
#  Results:
#
#	Returns:
#
#		$(INSTALL_DIR) $(INSTALL_ROOT)$1
#
#	for each selected directory.
#
#  Side effects:
#
#	None.
#

DS_DEFUN([DS_INSTALL_DIR],
[m4_ifelse($1,,,
[	@echo -en "Installing directory $1... "
	@$(INSTALL_DIR) $(INSTALL_ROOT)$1
	@echo "done"
DS_INSTALL_DIR(m4_shift($*))])])
DS_DEFUN([AM_INSTALL_DIR], [DS_INSTALL_DIR($*)])
#PAGE
# DS_INSTALL_DIRX --
#
#	Substitute the command used to install a directory, prefixing the
#	install directory with the value of "INSTALL_ROOT" and letting the
#	user select the owner, group and access permissions.
#
#  Arguments:
#
#	$1 -	the directory to install
#	$2 -	the access permissions, in octal form
#	$3 -	the user identifier
#	$4 -	the group identifier
#
#  Results:
#
#	Returns:
#
#		$(INSTALL_DIR) -m $2 -o $3 -g $4 $(INSTALL_ROOT)$1
#
#	for each selected directory.
#
#  Side effects:
#
#	None.
#

DS_DEFUN([DS_INSTALL_DIRX], [
	@echo -en "Installing directory $1... "
	@$(INSTALL_DIR)  -m $2 -o $3 -g $4 $(INSTALL_ROOT)$1
	@echo "done"
])
DS_DEFUN([AM_INSTALL_DIRX], [DS_INSTALL_DIRX($*)])
#PAGE
# DS_INSTALL_DATA --
#
#	Generate the commands used to install data files, prefixing the
#	install directory with the value of "INSTALL_ROOT". This is useful
#	to build a temporary installation tree and use it to build packages
#	and distribution archives.
#
#	  This macro works with a set of variables, all beginning with a
#	prefix identifying a set of files:
#
#	<prefix>_INSTLST -	the list of files to install;
#
#	<prefix>_INSTDIR -	the target directory.
#
#  Arguments:
#
#	$* -	the list of prefixes of the variables identifying the the
#		file sets
#
#  Results:
#
#	Returns:
#
#	   $(INSTALL_DIR) $(INSTALL_ROOT)$(<pfx>_INSTDIR) && \
# 	   $(INSTALL_DATA) $(<pfx>_INSTLST) $(INSTALL_ROOT)$(<pfx>_INSTDIR)
#
#	for each selected file set.
#
#  Side effects:
#
#	None.
#

DS_DEFUN([DS_INSTALL_DATA],
[m4_ifelse($1,,,[
	@echo "Installing $1 files... "
ifneq	(,$($1_INSTLST))
	@$(INSTALL_DIR) $(INSTALL_ROOT)$($1_INSTDIR)
	@$(INSTALL_DATA) $($1_INSTLST) $(INSTALL_ROOT)$($1_INSTDIR)
	@echo "Done."
else
	$(warning *** empty install list)
endif
DS_INSTALL_DATA(m4_shift($*))])])
DS_DEFUN([AM_INSTALL_DATA], [DS_INSTALL_DATA($*)])
#PAGE
# DS_INSTALL_BIN --
#
#	Generate the commands used to install executable files, prefixing the
#	install directory with the value of "INSTALL_ROOT". This is useful
#	to build a temporary installation tree and use it to build packages
#	and distribution archives.
#
#	  This macro works with a set of variables, all beginning with a
#	prefix identifying a set of files:
#
#	<prefix>_INSTLST -	the list of files to install;
#
#	<prefix>_INSTDIR -	the target directory.
#
#  Arguments:
#
#	$* -	the list of prefixes of the variables identifying the the
#		file sets
#
#  Results:
#
#	Returns:
#
#	   $(INSTALL_DIR) $(INSTALL_ROOT)$(<pfx>_INSTDIR) && \
# 	   $(INSTALL_BIN) $(<pfx>_INSTLST) $(INSTALL_ROOT)$(<pfx>_INSTDIR)
#
#	for each selected file set.
#
#  Side effects:
#
#	None.
#

DS_DEFUN([DS_INSTALL_BIN],
[m4_ifelse($1,,,[
	@echo -en "Installing $1 files... "
ifneq	(,$($1_INSTLST))
	@$(INSTALL_DIR) $(INSTALL_ROOT)$($1_INSTDIR)
	@$(INSTALL_BIN) $($1_INSTLST) $(INSTALL_ROOT)$($1_INSTDIR)
	@echo "done"
else
	$(warning *** empty install list)
endif
DS_INSTALL_BIN(m4_shift($*))])])
DS_DEFUN([AM_INSTALL_BIN], [DS_INSTALL_BIN($*)])
#PAGE
# DS_INSTALL_FILEX --
#
#	Generates the commands used to install files, prefixing the
#	install directory with the value of "INSTALL_ROOT". This is useful
#	to build a temporary installation tree and use it to build packages
#	and distribution archives.
#
#	  This macro works with a set of variables, all beginning with a
#	prefix identifying a set of files:
#
#	<prefix>_INSTLST -	the list of files to install;
#
#	<prefix>_INSTDIR -	the target directory;
#
#	<prefix>_OWNER -	the file owner;
#
#	<prefix>_GROUP -	the file group;
#
#	<prefix>_MODE -		the file access permissions.
#
#	<prefix>_DIRMODE -	the destination directory access
#				permissions.
#
#  Arguments:
#
#	$* -	the list of prefixes of the variables identifying the the
#		file sets
#
#  Results:
#
#	Returns:
#
#	   $(INSTALL) -m $(<pfx_DIRMODE) $(INSTALL_ROOT)$(<pfx>_INSTDIR) && \
# 	   $(INSTALL) -m $(<pfx>_MODE) -o $(<pfx>_OWNER) -g $(<pfx>_GROUP) \
#			$(<pfx>_INSTLST) $(INSTALL_ROOT)$(<pfx>_INSTDIR)
#
#	for each selected file set.
#
#  Side effects:
#
#	None.
#

DS_DEFUN([DS_INSTALL_FILEX],
[m4_ifelse($1,,,[
	@echo "Installing $1 files... "
ifneq	(,$($1_INSTLST))
	@$(INSTALL) -m $($1_DMODE) -d $(INSTALL_ROOT)$($1_INSTDIR)
	@$(INSTALL) -m $($1_FMODE) -o $($1_OWNER) -g $($1_GROUP) \
			$($1_INSTLST) $(INSTALL_ROOT)$($1_INSTDIR)
	@echo "Done."
else
	$(warning *** empty install list)
endif
DS_INSTALL_FILEX(m4_shift($*))])])
DS_DEFUN([AM_INSTALL_FILEX], [DS_INSTALL_FILEX($*)])


# Local Variables:
# mode: makefile
# page-delimiter: "^#PAGE$"
# End:
m4_divert(0)m4_dnl
