#!/bin/bash
# do.sh --
# 
# Part of: DevelStuff
# Contents: Helper script for Makefile rules.
# Date: Tue Nov 18, 2003
# 
# Abstract
# 
# 
# 
# Copyright (c) 2003, 2004 Marco Maggi
# 
# This is free  software you can redistribute it  and/or modify it under
# the terms of  the GNU General Public License as  published by the Free
# Software Foundation; either  version 2, or (at your  option) any later
# version.
# 
# This  file is  distributed in  the hope  that it  will be  useful, but
# WITHOUT   ANY  WARRANTY;  without   even  the   implied  warranty   of
# MERCHANTABILITY  or FITNESS  FOR A  PARTICULAR PURPOSE.   See  the GNU
# General Public License for more details.
# 
# You  should have received  a copy  of the  GNU General  Public License
# along with this file; see the file COPYING.  If not, write to the Free
# Software Foundation,  Inc., 59  Temple Place -  Suite 330,  Boston, MA
# 02111-1307, USA.
# 

# set -e
# set -x



#PAGE
## ------------------------------------------------------------
## Service variables required by MBFL.
## ------------------------------------------------------------

script_PROGNAME="do.sh"
script_AUTHOR="Marco Maggi"
script_COPYRIGHT_YEARS="2003, 2004"

script_VERSION="1.0"
script_LICENSE=GPL

script_USAGE="usage: ${script_PROGNAME} [options] ...
A script template.
Options:
\t   --package=NAME      selects the name of the package
\t   --version=NUM       selects the version number\n
\t   --dist              builds the source distribution archive\n
\t   --bindist           builds the binary distribution archives
\t   --bindist-bin       builds the binary distribution archive
\t                       for the bin section
\t   --bindist-doc       builds the binary distribution archive
\t                       for the doc section
\t   --bindist-dev       builds the binary distribution archive
\t                       for the dev section
\t   --bindist-sta       builds the binary distribution archive
\t                       for the sta section\n
\t   --debian            builds the binary distribution debian packages
\t   --debian-bin        builds the binary distribution debian package
\t                       for the bin section
\t   --debian-doc        builds the binary distribution debian package
\t                       for the doc section
\t   --debian-dev        builds the binary distribution debian package
\t                       for the dev section
\t   --debian-sta        builds the binary distribution debian package
\t                       for the sta section\n
\t   --top-srcdir=ARG    selects the top directory of the source tree
\t   --top-builddir=ARG  selects the top build directory
\t   --srcdir=DIR        selects the current source directory
\t   --builddir=DIR      selects the current build directory\n
\t   --archdir=DIR       where to store archives
\t   --tmpdir=DIR        selects a temporary directory (optional)\n
\t   --gzip              use gzip to compress the archives
\t   --bzip, --bzip2     use bzip2 to compress the archives\n
other options:
\t-i --interactive       ask before doing dangerous operations
\t-f --force             do not ask before dangerous operations
\t   --encoded-args      decode arguments following this option
\t                       from the hex format (example: 414243 -> ABC)
\t-v --verbose           verbose execution
\t   --silent            silent execution
\t   --null              use the null character as terminator
\t   --debug             print debug messages
\t   --test              tests execution
\t   --version           print version informations and exit
\t   --version-only      print version number and exit
\t   --license           print license informations and exit
\t-h --help --usage      print usage informations and exit
"

#PAGE
## ------------------------------------------------------------
## Global variables.
## ------------------------------------------------------------

mbfl_option_ACTION=

option_ARCHDIR="${PWD}"
option_COMPRESS=gzip

option_PACKAGE=
option_VERSION=

option_TOP_SRCDIR=
option_TOP_BUILDDIR=
option_SRCDIR=
option_BUILDDIR=
option_SECTION=

cmdl_TOP_SRCDIR=
cmdl_TOP_BUILDDIR=
cmdl_SRCDIR=
cmdl_BUILDDIR=

makefile_TOP_SRCDIR=
makefile_TOP_BUILDDIR=
makefile_SRCDIR=

#PAGE
## ------------------------------------------------------------
## Libraries.
## ------------------------------------------------------------

# libMBFL.m4 --
# 
# Part of: Marco's BASH Functions Library
# Contents: main library file
# Date: Fri Nov 28, 2003
# 
# Abstract
# 
# 
# 
# Copyright (c) 2003, 2004 Marco Maggi
# 
# This is free software; you  can redistribute it and/or modify it under
# the terms of the GNU Lesser General Public License as published by the
# Free Software  Foundation; either version  2.1 of the License,  or (at
# your option) any later version.
# 
# This library  is distributed in the  hope that it will  be useful, but
# WITHOUT   ANY  WARRANTY;   without  even   the  implied   warranty  of
# MERCHANTABILITY  or FITNESS  FOR A  PARTICULAR PURPOSE.   See  the GNU
# Lesser General Public License for more details.
# 
# You  should have  received a  copy of  the GNU  Lesser  General Public
# License along  with this library; if  not, write to  the Free Software
# Foundation, Inc.,  59 Temple Place,  Suite 330, Boston,  MA 02111-1307
# USA
# 


function mbfl_decode_hex () {
local in="${1:?}"
local len="${#in}"
local i=0
while test $i -lt $len
do
echo -en "\\x${in:$i:2}"
i=$(($i + 2))
done
return 0
}
function mbfl_decode_oct () {
local in="${1:?}"
local len="${#in}"
local i=0
while test $i -lt $len
do
echo -en "\\${in:$i:3}"
i=$(($i + 3))
done
return 0
}

function mbfl_file_extension () {
local file="${1:?}"
local i="${#file}"
local ch=
while test $i -ge 0
do
ch="${file:$i:1}"
if test "$ch" = "/"
then
break
elif test "$ch" = "."
then
i=$(($i + 1))
echo "${file:$i}"
break
fi
i=$(($i - 1))
done
return 0
}
function mbfl_file_dirname () {
local file="${1:?}"
local i="${#file}"
while test $i -ge 0
do
if test "${file:$i:1}" = "/"
then
while test \( $i -gt 0 \) -a \( "${file:$i:1}" = "/" \)
do i=$(($i - 1))
done
if test $i = 0
then echo "${file:$i:1}"
else
i=$(($i + 1))
echo "${file:0:$i}"
fi
return 0
fi
i=$(($i - 1))
done
echo "."
return 0
}
function mbfl_file_normalise () {
local pathname="${1:?}"
local prefix="${2}"
if test -z "${prefix}"; then
prefix="${PWD}"
fi
if test "${pathname:0:1}" = "/"; then
echo "${pathname}"
elif test -d "${prefix}"; then
cd "${prefix}" >/dev/null
if test -d "${pathname}"; then
cd "${pathname}" >/dev/null
echo "${PWD}"
cd - >/dev/null
else
local tailname=$(mbfl_file_tail "${pathname}")
local dirname=$(mbfl_file_dirname "${pathname}")
if test -d "${dirname}"; then
cd "${dirname}" >/dev/null
echo "${PWD}/${tailname}"
cd - >/dev/null
else
echo "${prefix}/${pathname}"
fi
fi
else
echo "${prefix}/${pathname}"
fi
return 0
}
function mbfl_file_rootname () {
local file="${1:?}"
local i="${#file}"
if test $i = 1
then
echo "${file}"
return 0
fi
while test $i -ge 0
do
ch="${file:$i:1}"
if test "$ch" = "."
then
if test $i -gt 0
then
echo "${file:0:$i}"
break
else
echo "${file}"
fi
elif test "$ch" = "/"
then
echo "${file}"
break
fi
i=$(($i - 1))
done
return 0
}
function mbfl_file_split () {
local file="${1:?}"
echo -e "${file//\//\\n}"
return 0
}
function mbfl_file_tail () {
local file="${1:?}"
local i="${#file}"
while test $i -ge 0
do
ch="${file:$i:1}"
if test "$ch" = "/"
then
i=$(($i + 1))
echo "${file:$i}"
return 0
fi
i=$(($i - 1))
done
echo "${file}"
return 0
}
function mbfl_file_find_tmpdir () {
local TMPDIR="${1}"
if test -n "${TMPDIR}" -a -d "${TMPDIR}" -a -w "${TMPDIR}"
then
echo "${TMPDIR}"
return 0
fi
if test -n "${USER}"
then
TMPDIR="/tmp/${USER}"
if test -n "${TMPDIR}" -a -d "${TMPDIR}" -a -w "${TMPDIR}"
then
echo "${TMPDIR}"
return 0
fi
fi
TMPDIR=/tmp
if test -n "${TMPDIR}" -a -d "${TMPDIR}" -a -w "${TMPDIR}"
then
echo "${TMPDIR}"
return 0
fi
mbfl_message_error "cannot find usable value for TMPDIR"
return 1
}

ARGC=0
ARGC1=0
declare -a ARGV ARGV1
while test $# -gt 0
do
ARGV1[$ARGC1]="$1"
ARGC1=$(($ARGC1 + 1))
shift
done
function mbfl_getopts_parse () {
local OPT= OPTARG=
local arg= end=0 i=0
while test $i -lt $ARGC1
do
arg="${ARGV1[$i]}"
if test "$end" = 1
then
ARGV[$ARGC]="${arg}"
ARGC=$(($ARGC + 1))
elif test "${arg}" = "--"
then end=1
elif mbfl_getopts_isbrief "${arg}" OPT || \
mbfl_getopts_islong "${arg}" OPT
then mbfl_getopts_option "${OPT}"
elif \
mbfl_getopts_isbrief_with "${arg}" OPT OPTARG || \
mbfl_getopts_islong_with  "${arg}" OPT OPTARG
then mbfl_getopts_option_with "${OPT}" "${OPTARG}"
else
ARGV[$ARGC]="${arg}"
ARGC=$(($ARGC + 1))
fi
i=$(($i + 1))
done
return 0
}
function mbfl_getopts_option () {
local OPT="${1:?}"
local i=0
case "${OPT}" in
	encoded-args)
	    mbfl_option_ENCODED_ARGS="yes"
	    ;;
	v|verbose)
	    mbfl_option_VERBOSE="yes"
	    mbfl_message_VERBOSE="yes"
	    ;;
	silent)
	    mbfl_option_VERBOSE="no"
	    mbfl_message_VERBOSE="no"
	    ;;
	debug)
	    mbfl_option_DEBUG="yes"
	    mbfl_message_DEBUG="yes"
	    ;;
	test)
	    mbfl_program_TEST="yes"
	    ;;
	null)
	    mbfl_option_NULL="yes"
	    ;;
f|force)
	    mbfl_option_INTERACTIVE="no"
	    ;;
i|interactive)
	    mbfl_option_INTERACTIVE="yes"
	    ;;
	version)
	    echo -e "${mbfl_message_VERSION}"
	    exit 0
	    ;;
	version-only)
	    echo -e "${script_VERSION}"
	    exit 0
	    ;;
	license)
case "${script_LICENSE}" in
GPL)
echo -e "${mbfl_message_LICENSE_GPL}"
;;
LGPL)
echo -e "${mbfl_message_LICENSE_GPLL}"
;;
BSD)
echo -e "${mbfl_message_LICENSE_BSD}"
;;
*)
mbfl_message_error "unknown license: \"${script_LICENSE}\""
exit 2
;;
esac
	    exit 0
	    ;;
	h|help|usage)
	    echo -e "${script_USAGE}"
	    exit 0
	    ;;
	*)
if ! script_option "${OPT}"; then
mbfl_message_error "unknown option: \"${OPT}\""
exit 2
fi
	    ;;
esac
return 0
}
function mbfl_getopts_option_with () {
local OPT="${1:?}"
local OPTARG="${2:?}"
if test "${mbfl_option_ENCODED_ARGS}" = "yes"; then
OPTARG=$(mbfl_decode_hex "${OPTARG}")
fi
case "${OPT}" in
	*)
	    if ! script_option_with "${OPT}" "${OPTARG}"; then
mbfl_message_error "unknown option \"${OPT}\""
exit 2
fi
	    ;;
esac
return 0
}
function mbfl_getopts_islong () {
local arg="${1:?missing argument to mbfl_getopts_islong()}"
local optvar="${2}"
local len="${#arg}"
if test $len -lt 3
then return 1
fi
if test "${arg:0:1}" = "-" -a "${arg:1:1}" = "-"
then
local i=2
local ch=
while test $i -lt $len
do
ch="${arg:$i:1}"
if test \
\( "$ch" \< A -o Z \< "$ch" \) -a \
\( "$ch" \< a -o z \< "$ch" \) -a \
\( "$ch" \< 0 -o 9 \< "$ch" \) -a \
"$ch" != _ -a "$ch" != -
then return 1
fi
i=$(($i + 1))
done
if test -n "${optvar}"
then eval ${optvar}="${arg:2}"
fi
return 0
fi
return 1
}
function mbfl_getopts_islong_with () {
local arg="${1:?missing argument to mbfl_getopts_islong_with()}"
local optvar="${2}"
local valvar="${3}"
local len="${#arg}" str=
# The min length of a long option with is 5 (example: --o=1).
if test $len -lt 5 -o "${arg:0:1}" != "-" -o "${arg:1:1}" != "-"
then return 1
fi
local j=0
while test $j -lt $len
do
ch="${arg:$j:1}"
if test "$ch" = "="
then
if test $(($j + 1)) = $len
then return 1
fi
if mbfl_getopts_islong "${arg:0:$j}"
then
if test -n "${optvar}"
then eval ${optvar}="${arg:2:$(($j - 2))}"
fi
if test -n "${valvar}"
then
str=$(mbfl_getopts_quote_string "${arg:$(($j + 1))}")
eval "${valvar}=\"${str}\""
fi
return 0
else return 1
fi
fi
j=$(($j + 1))
done
return 1
}
function mbfl_getopts_isbrief () {
local arg="${1:?missing argument to mbfl_getopts_isbrief()}"
local optvar="${2}"
local ch="${arg:1:1}"
if test "${#arg}" = 2 -a "${arg:0:1}" = "-"
then
if test \( "$ch" \< A -o Z \< "$ch" \) -a \
\( "$ch" \< a -o z \< "$ch" \) -a \
\( "$ch" \< 0 -o 9 \< "$ch" \)
then return 1
else
if test -n "${optvar}"
then eval ${optvar}="${arg:1}"
fi
return 0
fi
else return 1
fi
}
function mbfl_getopts_isbrief_with () {
local arg="${1:?missing argument to mbfl_getopts_isbrief_with()}"
local optvar="${2}"
local valvar="${3}"
local ch="${arg:1:1}" str=
if test "${#arg}" -gt 2 -a "${arg:0:1}" = "-" -a "${arg:1:1}" != "-"
then
if test \( "$ch" \< A -a z \< "$ch" \) -a \
\( "$ch" \< 0 -a 9 \< "$ch" \)
then return 1
else
if test -n "${optvar}"
then eval ${optvar}="${arg:1:1}"
fi
if test -n "${valvar}"
then
str=$(mbfl_getopts_quote_string "${arg:2}")
eval "${valvar}=\"${str}\""
fi
return 0
fi
else return 1
fi
}
function mbfl_getopts_decode_hex () {
local i=0
while test $i -lt $ARGC
do
ARGV[$i]=$(mbfl_decode_hex "${ARGV[$i]}")
i=$(($i + 1))
done
return 0
}
function mbfl_wrong_num_args () {
local required="${1:?missing required number of args in mbfl_wrong_num_args()}"
local argc="${2:?missing given number of args in mbfl_wrong_num_args()}"
if test $required = $argc
then
return 0
else
mbfl_message_error "$required argument(s) required"
return 1
fi
}
function mbfl_getopts_quote_string () {
local STR="${1:?missing string to mbfl_getopts_quote_string()}"
local OUT=
local len="${#STR}" i=0 ch=

while test $i -lt $len
do
ch="${STR:$i:1}"
if test "$ch" = \\
then ch=\\\\
fi
OUT="${OUT}$ch"
i=$(($i + 1))
done
echo "$OUT"
return 0
}
function mbfl_argv_from_stdin () {
local file=
if test $ARGC -eq 0
then
	if test "${mbfl_option_NULL}" = "yes"; then
	    while read -d $'\x00' file
	      do
	      ARGV[$ARGC]="${file}"
	      ARGC=$(($ARGC + 1))
	    done
	else
	    while read file
	      do
	      ARGV[$ARGC]="${file}"
	      ARGC=$(($ARGC + 1))
	    done
	fi
fi
return 0
}
function mbfl_argv_all_files () {
local i=0
local file=
while test $i -lt $ARGC
do
	file="${ARGV[$i]}"
	file=$(mbfl_file_normalise "${file}")
	if test ! -f "${file}"
	then
	    mbfl_message_error "unexistent file \"${file}\""
	    return 1
	fi
	ARGV[$i]="${file}"
	i=$(($i + 1))
done
return 0
}

mbfl_message_PROGNAME="${0}"
mbfl_message_VERBOSE="no"
mbfl_message_DEBUGGING="no"
mbfl_message_STDERR="2"
function mbfl_message_set_progname () {
local PROGNAME="${1:?}"
mbfl_message_PROGNAME="${PROGNAME}"
return 0
}
function mbfl_message_set_verbosity () {
local VERBOSE="${1:?}"
mbfl_message_VERBOSE="${VERBOSE}"
return 0
}
function mbfl_message_set_debugging () {
local DEBUGGING="${1:?}"
mbfl_message_DEBUGGING="${DEBUGGING}"
return 0
}
function mbfl_message_set_stderr () {
local STDERR="${1:?}"
mbfl_message_STDERR="${STDERR}"
return 0
}
function mbfl_message_string () {
local MSG="${1:?missing argument to \"mbfl_message_string\"}"
echo -ne "${mbfl_message_PROGNAME}: ${MSG}" >&${mbfl_message_STDERR}
return 0
}
function mbfl_message_verbose () {
local MSG="${1:?missing argument to \"mbfl_message_verbose\"}"
if test "${mbfl_message_VERBOSE}" = 'yes'
then echo -ne "${mbfl_message_PROGNAME}: ${MSG}" >&${mbfl_message_STDERR}
fi
return 0
}
function mbfl_message_verbose_end () {
local MSG="${1:?missing argument to \"mbfl_message_verbose_end\"}"
if test "${mbfl_message_VERBOSE}" = 'yes'
then echo -ne "${MSG}" >&${mbfl_message_STDERR}
fi
return 0
}
function mbfl_message_debug () {
local MSG="${1:?missing argument to \"mbfl_message_debug\"}"
if test "${mbfl_message_DEBUGGING}" = 'yes'
then echo -ne "${mbfl_message_PROGNAME}: ${MSG}" >&${mbfl_message_STDERR}
fi
return 0
}
function mbfl_message_warning () {
local MSG="${1:?missing argument to \"mbfl_message_warning\"}"
echo -e "${mbfl_message_PROGNAME} warning: ${MSG}" >&${mbfl_message_STDERR}
return 0
}
function mbfl_message_error () {
local MSG="${1:?missing argument to \"mbfl_message_error\"}"
echo -e "${mbfl_message_PROGNAME} error: ${MSG}" >&${mbfl_message_STDERR}
return 0
}

function mbfl_program_check () {
local PROGRAMS=${*}
for item in ${PROGRAMS}
do
if test ! -x "${item}"
then
mbfl_message_error "cannot find executable \"${item}\""
return 1
fi
done
return 0
}
function mbfl_program_exec () {
if test "${mbfl_program_TEST}" = "yes"; then
echo "${@}" >&2
return 0
else
eval "${@}"
return $?
fi
}

declare -a MBFL_SIGNAL_MAP
declare -a MBFL_SIGNAL_HANDLERS
declare -a MBFL_SIGNAL_REGISTRY
function mbfl_signal_map_signame_to_signum () {
local SIGSPEC="${1:?}"
declare -i signum=0
while test -n "${MBFL_SIGNAL_MAP[${signum}]}"
do
if test "${MBFL_SIGNAL_MAP[${signum}]}" = "${SIGSPEC}"
then break
fi
signum=${signum}+1
done
MBFL_SIGNAL_MAP[$signum]="${SIGSPEC}"
echo ${signum}
return 0
}
function mbfl_signal_register_handler () {
local HANDLER="${1:?}"
declare -i hannum
hannum=$((${#MBFL_SIGNAL_HANDLERS[*]} + 1))
MBFL_SIGNAL_HANDLERS[${hannum}]="${HANDLER}"
return 0
}
function mbfl_signal_attach () {
local SIGSPEC="${1:?}"
local HANDLER="${2:?}"
declare -i signum=0 hannum=0
# Append  the handler  number  to the  list  of registered  handlers
# associated to the signal number.
MBFL_SIGNAL_REGISTRY[$signum]="${MBFL_SIGNAL_REGISTRY[$signum]} $hannum"
trap "mbfl_signal_handler ${signum}" ${SIGSPEC}
echo $hannum
return 0
}
function mbfl_signal_detach () {
local hannum="${1:?}"
if test -n "${MBFL_SIGNAL_HANDLERS[${hannum}]}"
then
MBFL_SIGNAL_HANDLERS[${hannum}]=
return 0
else
mbfl_message_error "signal handler not found when detaching"
return 1
fi
}
function mbfl_signal_handler () {
local signum="${1:?}"
local HANDLER=
declare -i signum=0 hannum=
for hannum in ${MBFL_SIGNAL_REGISTRY[$signum]}
do
HANDLER="${MBFL_SIGNAL_HANDLERS[$hannum]}"
if test -n "${HANDLER}"
then eval ${HANDLER}
fi
done
return 0
}
function mbfl_signal_inspect () {
local SIGSPEC=
local HANDLER=
declare -i signum=0 hannum=
mbfl_message_string "Inspecting signal table:\n"
while test $signum -lt ${#MBFL_SIGNAL_MAP[*]}
do
SIGSPEC="${MBFL_SIGNAL_MAP[${signum}]}"
if test -z "${SIGSPEC}"
then break
fi
for handnum in ${MBFL_SIGNAL_REGISTRY[${signum}]}
do
HANDLER="${MBFL_SIGNAL_HANDLERS[${handnum}]}"
if test -z "${HANDLER}"
then break
fi
echo "Signal \"${SIGSPEC}\": ${HANDLER} "
done
signum=${signum}+1
done
mbfl_message_string "End inspection.\n"
return 0
}

function mbfl_string_chars () {
local string="${1:?}"
local i=0
while test $i -lt "${#string}"
do
echo ${string:$i:1}
i=$(($i + 1))
done
}
function mbfl_string_first () {
local string="${1:?}"
local char="${2:?}"
local begin="${3:-0}"
local i=$begin
while test "$i" -lt "${#string}"
do
if test "${string:$i:1}" = "$char"
then
echo $i
return 0
fi
i=$(($i+1))
done
return 0
}
function mbfl_string_index () {
local string="${1:?}"
local index="${2:?}"
echo "${string:$index:1}"
}
function mbfl_string_is () {
local class="${1:?null class to mbfl_string_is}"
local string="${2}"
local ch=
local flag=0
test "${#string}" -eq 0 && return 1
case "$class" in
alpha)
{
local i=0
while test $i -lt "${#string}"
do
ch="${string:$i:1}"
if test \
\( "$ch" \< A -o Z \< "$ch" \) -a \
\( "$ch" \< a -o z \< "$ch" \)
then return 1
fi
i=$(($i + 1))
done
} || flag=1
;;
alnum)
{
local i=0
while test $i -lt "${#string}"
do
ch="${string:$i:1}"
if test \
\( "$ch" \< A -o Z \< "$ch" \) -a \
\( "$ch" \< a -o z \< "$ch" \) -a \
\( "$ch" \< 0 -o 9 \< "$ch" \)
then return 1
fi
i=$(($i + 1))
done
} || flag=1
;;
digit)
{
local i=0
while test $i -lt "${#string}"
do
ch="${string:$i:1}"
if test \( "$ch" \< 0 -o 9 \< "$ch" \)
then return 1
fi
i=$(($i + 1))
done
} || flag=1
;;
noblank)
local i=0
local len="${#string}"
while test $i -lt $len
do
ch="${string:$i:1}"
if test "$ch" = " "   -o "$ch" = $'\n' -o \
"$ch" = $'\r' -o "$ch" = $'\t' -o \
"$ch" = $'\f'
then return 1
fi
i=$(($i + 1))
done
return 0
;;
name)
local i=1
local len="${#string}"
local ch=
if test $len -eq 0
then return 1
else
ch="${string:0:1}"
if test \( "$ch" != _ \) -a \
\( "$ch" \< A -o Z \< "$ch" \) -a \
\( "$ch" \< a -o z \< "$ch" \)
then return 1
fi
while test $i -lt $len
do
ch="${string:$i:1}"
if test \( "$ch" != _ \) -a \
\( "$ch" \< A -o Z \< "$ch" \) -a \
\( "$ch" \< a -o z \< "$ch" \) -a \
\( "$ch" \< 0 -o 9 \< "$ch" \)
then return 1
fi
i=$(($i + 1))
done
fi
return 0
;;
esac
return $flag
}
function mbfl_string_last () {
local string="${1:?}"
local char="${2:?}"
local begin="${3:-${#string}}"
local i=$begin
while test "$i" -gt -1
do
if test "${string:$i:1}" = "$char"
then
echo $i
return 0
fi
i=$(($i - 1))
done
return 0
}
function mbfl_string_range () {
local string="${1:?}"
local begin="${2:?}"
local end="${3}"
if test -z "$end" -o "$end" = "end"
then echo "${string:$begin}"
else echo "${string:$begin:$end}"
fi
}
function mbfl_string_split () {
local string="${1:?}"
local chars="${2:?}"
local i=0
local j=0
local sep=
while test $i -lt "${#chars}"
do
sep="${chars:$i:1}"
j=0
while test $j -lt "${#string}"
do
string="${string//${sep}/\\n}"
j=$(($j + 1))
done
i=$(($i + 1))
done
echo -e "$string"
return 0
}

function mbfl_dialog_yes_or_no () {
local STRING="${1:?}"
local ANS=
read -e -p "${STRING}? (yes/no) " ANS
while test "$ANS" != 'yes' -a "$ANS" != 'no'
do
echo 'Please answer yes or no.'
read -e -p "install?(yes/no) " ANS
done
if test "$ANS" = yes; then
return 0
else
return 1
fi
}

mbfl_option_VERBOSE="no"
mbfl_option_DEBUG="no"
mbfl_option_TEST="no"
mbfl_option_INTERACTIVE="no"
mbfl_option_ENCODED_ARGS="no"
mbfl_option_TMPDIR="${TMPDIR:-/tmp}"
mbfl_option_ACTION=
mbfl_ORG_PWD="${PWD}"
mbfl_message_LICENSE_GPL="${script_PROGNAME} version ${script_VERSION}
Written by ${script_AUTHOR}.\n
Copyright (C) ${script_COPYRIGHT_YEARS} by ${script_AUTHOR}.\n
This file  is free software you  can redistribute it  and/or modify it
under the terms of the GNU  General Public License as published by the
Free Software  Foundation; either version  2, or (at your  option) any
later version.\n
This  file is  distributed in  the hope  that it  will be  useful, but
WITHOUT   ANY  WARRANTY;   without  even   the  implied   warranty  of
MERCHANTABILITY  or FITNESS  FOR A  PARTICULAR PURPOSE.   See  the GNU
General Public License for more details.\n
You  should have received  a copy  of the  GNU General  Public License
along with this file; see the file COPYING.  If not, write to the Free
Software Foundation,  Inc., 59  Temple Place -  Suite 330,  Boston, MA
02111-1307, USA.
"
mbfl_message_LICENSE_LGPL="${script_PROGNAME} version ${script_VERSION}
Written by ${script_AUTHOR}.\n
Copyright (C) ${script_COPYRIGHT_YEARS} by ${script_AUTHOR}.\n
This is free software; you  can redistribute it and/or modify it under
the terms of the GNU Lesser General Public License as published by the
Free Software  Foundation; either version  2.1 of the License,  or (at
your option) any later version.\n
This library  is distributed in the  hope that it will  be useful, but
WITHOUT   ANY  WARRANTY;   without  even   the  implied   warranty  of
MERCHANTABILITY  or FITNESS  FOR A  PARTICULAR PURPOSE.   See  the GNU
Lesser General Public License for more details.\n
You  should have  received a  copy of  the GNU  Lesser  General Public
License along  with this library; if  not, write to  the Free Software
Foundation, Inc.,  59 Temple Place,  Suite 330, Boston,  MA 02111-1307
USA.
"
mbfl_message_LICENSE_BSD="${script_PROGNAME} version ${script_VERSION}
Written by ${script_AUTHOR}.\n
Copyright (C) ${script_COPYRIGHT_YEARS} by ${script_AUTHOR}.\n
The author  hereby grant permission to use,  copy, modify, distribute,
and  license this  software  and its  documentation  for any  purpose,
provided that  existing copyright notices  are retained in  all copies
and that  this notice  is included verbatim  in any  distributions. No
written agreement, license, or royalty  fee is required for any of the
authorized uses.  Modifications to this software may be copyrighted by
their authors and need not  follow the licensing terms described here,
provided that the new terms are clearly indicated on the first page of
each file where they apply.\n
IN NO  EVENT SHALL THE AUTHOR  OR DISTRIBUTORS BE LIABLE  TO ANY PARTY
FOR  DIRECT, INDIRECT, SPECIAL,  INCIDENTAL, OR  CONSEQUENTIAL DAMAGES
ARISING OUT  OF THE  USE OF THIS  SOFTWARE, ITS DOCUMENTATION,  OR ANY
DERIVATIVES  THEREOF, EVEN  IF THE  AUTHOR  HAVE BEEN  ADVISED OF  THE
POSSIBILITY OF SUCH DAMAGE.\n
THE  AUTHOR  AND DISTRIBUTORS  SPECIFICALLY  DISCLAIM ANY  WARRANTIES,
INCLUDING,   BUT   NOT  LIMITED   TO,   THE   IMPLIED  WARRANTIES   OF
MERCHANTABILITY,    FITNESS   FOR    A    PARTICULAR   PURPOSE,    AND
NON-INFRINGEMENT.  THIS  SOFTWARE IS PROVIDED  ON AN \"AS  IS\" BASIS,
AND  THE  AUTHOR  AND  DISTRIBUTORS  HAVE  NO  OBLIGATION  TO  PROVIDE
MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
"
mbfl_message_VERSION="${script_PROGNAME} version ${script_VERSION}
Written by ${script_AUTHOR}.\n
Copyright (C) ${script_COPYRIGHT_YEARS} by ${script_AUTHOR}.\n
This is  free software; see the  source or use the  --license option for
copying conditions.  There is NO warranty; not  even for MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.
"
function mbfl_main () {
local exit_code=0
mbfl_message_set_progname "${script_PROGNAME}"
mbfl_getopts_parse
if test "${mbfl_option_ENCODED_ARGS}" = "yes"; then
	mbfl_getopts_decode_hex
fi
mbfl_message_set_verbosity "${mbfl_option_VERBOSE}"
mbfl_message_set_debugging "${mbfl_option_DEBUG}"
if test "${mbfl_option_TEST}" = "yes"; then
	mbfl_message_string "test execution\n"
fi
script_begin || exit $?
if test -n "${mbfl_option_ACTION}"; then
	script_action_"${mbfl_option_ACTION}"
	exit_code=$?
fi
script_end || exit $?
exit $exit_code
}


### end of file
# Local Variables:
# mode: sh
# page-delimiter: "^#PAGE$"
# End:


#PAGE
function script_begin () {
    process_options
    return 0
}
function script_end () {
    return 0
}
function script_option () {
    local OPTNAME="${1}"


    case "${OPTNAME}" in
	*)
	    return 2
	    ;;
    esac
    return 0
}
#PAGE
# process_options --
#
#	Processes options from the Makefile and the command line
#	giving precedence to the ones from the command line.
#
#	  Values from the Makefile are stored in global variables,
#	prefixed with "makefile_", that are declared empty and
#	filled with values only if the corresponding variable is
#	found in the Makefile.
#
#	  Values from the command line are stored in global
#	variables, prefixed with "cmdl_", that are declared empty
#	and filled with values only if the corresponding option
#	is used on the command line.
#
#	  Command line arguments are processed first to allow the
#	user to select a value for the build directory: the one in
#	which we expect to find the Makefile; the build directory
#	may be its own variable in the Makefile, but we are not
#	interested in it: we assume that the directory in which
#	the Makefile is located is the build directory. If the
#	option is not used: "parse_makefile()" will look for the
#	Makefile in the current directory.
#
#  Arguments:
#
#	None.
#
#  Results:
#
#	Returns with code zero, or code one if an error occurs.
#

function process_options () {
    local tmp=


    tmp="${cmdl_BUILDDIR}"
    if test -z "${tmp}"; then
	tmp="${PWD}"
    else
	tmp=$(mbfl_file_normalise "${tmp}")
    fi
    parse_makefile "${tmp}" || return 1

    if test -n "${cmdl_BUILDDIR}"; then
	option_BUILDDIR="${cmdl_BUILDDIR}"
    else
	option_BUILDDIR="${PWD}"
    fi

    if test -n "${makefile_TOP_SRCDIR}"
	then option_TOP_SRCDIR="${makefile_TOP_SRCDIR}"
    fi
    if test -n "${cmdl_TOP_SRCDIR}"
	then option_TOP_SRCDIR="${cmdl_TOP_SRCDIR}"
    fi
    if test -z "${option_TOP_SRCDIR}" -o ! -d "${option_TOP_SRCDIR}"
	then
	mbfl_message_error "null or invalid top_srcdir value (${option_TOP_SRCDIR})"
	return 1
    fi

    if test -n "${makefile_TOP_BUILDDIR}"
	then option_TOP_BUILDDIR="${makefile_TOP_BUILDDIR}"
    fi
    if test -n "${cmdl_TOP_BUILDDIR}"
	then option_TOP_BUILDDIR="${cmdl_TOP_BUILDDIR}"
    fi

    if test -n "${makefile_SRCDIR}"
	then option_SRCDIR="${makefile_SRCDIR}"
    fi
    if test -n "${cmdl_SRCDIR}"
	then option_SRCDIR="${cmdl_SRCDIR}"
    fi

    if test -n "${makefile_PACKAGE}"
	then option_PACKAGE="${makefile_PACKAGE}"
    fi
    if test -n "${cmdl_PACKAGE}"
	then option_PACKAGE="${cmdl_PACKAGE}"
    fi

    if test -n "${makefile_VERSION}"
	then option_VERSION="${makefile_VERSION}"
    fi
    if test -n "${cmdl_VERSION}"
	then option_VERSION="${cmdl_VERSION}"
    fi
    return 0
}
#PAGE
# parse_makefile --
#
#	Reads the Makefile in the selected build directory.
#
#  Arguments:
#
#	$1 -		The build directory in which look for
#			the Makefile.
#
#  Results:
#
#	Returns with code zero, or code one if an error occurs.
#

function parse_makefile () {
    local builddir="${1:?missing builddir argument for parse_makefile()}"
    local makefile=


    if test -z "${builddir}"; then
	builddir=.
    elif test ! -d "${builddir}"; then
	mbfl_message_error "unexistent build directory (${builddir})"
	return 1
    fi

    makefile="${builddir}/Makefile"
    if test ! -f "${makefile}";	then
	mbfl_message_error "unable to find Makefile (${makefile})"
	return 1
    fi

    if ! makefile_TOP_SRCDIR=$(makefile_variable "${makefile}" top_srcdir)
	then return 1
    fi
    if test -n "${makefile_TOP_SRCDIR}"; then
	makefile_TOP_SRCDIR=$(mbfl_file_normalise \
	    "${makefile_TOP_SRCDIR}" "${builddir}")
    fi

    if ! makefile_TOP_BUILDDIR=$(makefile_variable "${makefile}" top_builddir)
	then return 1
    fi
    if test -n "${makefile_TOP_BUILDDIR}"; then
	makefile_TOP_BUILDDIR=$(mbfl_file_normalise \
	    "${makefile_TOP_BUILDDIR}" "${builddir}")
    fi

    if ! makefile_SRCDIR=$(makefile_variable "${makefile}" srcdir)
	then return 1
    fi
    if test -n "${makefile_SRCDIR}"; then
	makefile_SRCDIR=$(mbfl_file_normalise \
	"${makefile_SRCDIR}" "${builddir}")
    fi

    if ! makefile_PACKAGE=$(makefile_variable "${makefile}" PACKAGE_NAME)
	then return 1
    fi

    if ! makefile_VERSION=$(makefile_variable "${makefile}" PACKAGE_XVERSION)
	then return 1
    fi
    return 0
}
#PAGE
# makefile_variable --
#
#	Acquires the value of a variable from the Makefile.
#	Directory variables may hold values relative to the
#	directory in which the Makefile is located: these
#	values should be normalised before their usage.
#
#  Arguments:
#
#	$1 -		The selected Makefile.
#	$2 -		The variable name.
#
#  Results:
#
#	Echoes to stdout the value of the variable. Returns
#	with code zero, or one if an error occurs.
#

function makefile_variable () {
    local MAKE=$(type -path make)
    local MAKEFLAGS="--no-print-directory --file=${1:?}"


    mbfl_program_check "${MAKE}" || return 1
    ${MAKE} ${MAKEFLAGS} echo-variable VARIABLE="${2:?}" || return 1
    return 0
}
#PAGE
function script_option () {
    local OPT="${1:?}"

    case "${OPT}" in
	dist)
	    mbfl_option_ACTION="dist"
	    ;;

	bindist)
	    mbfl_option_ACTION="bindist"
	    ;;
	bindist-bin)
	    option_SECTION=bin
	    mbfl_option_ACTION="bindist"
	    ;;
	bindist-doc)
	    option_SECTION=doc
	    mbfl_option_ACTION="bindist"
	    ;;
	bindist-dev)
	    option_SECTION=dev
	    mbfl_option_ACTION="bindist"
	    ;;
	bindist-sta)
	    option_SECTION=sta
	    mbfl_option_ACTION="bindist"
	    ;;

	debian)
	    mbfl_option_ACTION="debian"
	    ;;
	debian-bin)
	    option_SECTION=bin
	    mbfl_option_ACTION="debian"
	    ;;
	debian-doc)
	    option_SECTION=doc
	    mbfl_option_ACTION="debian"
	    ;;
	debian-dev)
	    option_SECTION=dev
	    mbfl_option_ACTION="debian"
	    ;;
	debian-sta)
	    option_SECTION=sta
	    mbfl_option_ACTION="debian"
	    ;;

	gzip)
	    option_COMPRESS=gzip
	    ;;
	bzip|bzip2)
	    option_COMPRESS=bzip
	    ;;

	*)
	    return 2
	    ;;
    esac
    return 0
}
#PAGE
function script_option_with () {
    local OPT="${1:?}"
    local OPTARG="${2:?}"


    case "$OPT" in
	package)
	    cmdl_PACKAGE="${OPTARG}"
	    ;;
	version)
	    cmdl_VERSION="${OPTARG}"
	    ;;

	top-srcdir)
	    if test -n "${OPTARG}"; then
		cmdl_TOP_SRCDIR=$(mbfl_file_normalise "${OPTARG}")
	    fi
	    ;;
	top-builddir)
	    if test -n "${OPTARG}"; then
		cmdl_TOP_BUILDDIR=$(mbfl_file_normalise "${OPTARG}")
	    fi
	    ;;
	builddir)
	    if test -n "${OPTARG}"; then
		cmdl_BUILDDIR=$(mbfl_file_normalise "${OPTARG}")
	    fi
	    ;;
	srcdir)
	    if test -n "${OPTARG}"; then
		cmdl_SRCDIR=$(mbfl_file_normalise "${OPTARG}")
	    fi
	    ;;

	archdir)
	    if test -n "${OPTARG}"; then
		option_ARCHDIR=$(mbfl_file_normalise "${OPTARG}")
	    fi
	    ;;
	tmpdir)
	    if test -n "${OPTARG}"; then
		option_TMPDIR=$(mbfl_file_normalise "${OPTARG}")
	    fi
	    ;;

	*)
	    return 2
	    ;;
    esac
    return 0
}
#PAGE
function script_action_dist () {
    local package="${option_PACKAGE}"
    local version="${option_VERSION}"
    local top_srcdir="${option_TOP_SRCDIR}"
    local archdir="${option_ARCHDIR}"
    local archive=
    local distdir=
    local pkgdir=
    local pwd="${PWD}"

    local MKDIR=$(type -path mkdir)
    local MKDIR_FLAGS="--parents --mode=0700"
    local TAR=$(type -path tar)
    local TAR_FLAGS=
    local RM=$(type -path rm)


    # Test preconditions.

    if test -z "${package}"
	then
	mbfl_message_error "null package, use --package"
	return 1
    fi

    if test -z "${version}"
	then
	mbfl_message_error "null version, use --version"
	return 1
    fi

    if ! TMPDIR=$(mbfl_file_find_tmpdir "${option_TMPDIR}")
	then return 1
    fi

    if ! mbfl_program_check "${MKDIR}" "${TAR}" "${RM}"
	then return 1
    fi

    if test ! -d "${archdir}"; then
	mbfl_message_error "unexistent destination directory (${archdir})"
	return 1
    fi


    # Build the name of the  source archive. Check also the availability
    # of the compressor program: we need it to allow "tar" to unpack the
    # archive.

    archive="${package}_${version}_src.tar"

    case "${option_COMPRESS}" in
	gzip)
	    mbfl_program_check "${program_GZIP}" || return 1
	    TAR_FLAGS="--gzip"
	    archive="${archive}.gz"
	    ;;
	bzip)
	    mbfl_program_check "${program_BZIP2}" || return 1
	    TAR_FLAGS="--bzip2"
	    archive="${archive}.bz2"
	    ;;
    esac


    distdir="${TMPDIR}/dist"
    pkgdir="${package}_${version}"


    mbfl_message_verbose "building distribution archive\n"
    mbfl_message_verbose "archive: ${archive}\n"
    mbfl_message_verbose "temporary directory: ${distdir}\n"
    mbfl_message_verbose "archive in: ${archdir}\n"

    mbfl_program_exec ${MKDIR} ${MKDIR_FLAGS} "${distdir}/${pkgdir}"

    mbfl_program_exec ${TAR} --directory="${top_srcdir}"			\
	--create --file=- --dereference			\
	--exclude=RCS		--exclude=CVS		\
	--exclude=archives	--exclude=\*.ps			\
	--exclude=\*.dvi	--exclude=tmp			\
	--exclude=\*.gz		--exclude=\*.tar	\
	--exclude=\*.so		--exclude=\*.o		\
	--exclude=\*.a		--exclude=\*.rpm	\
	--exclude=\*.deb	--exclude=.emacs\*		\
	--exclude=\*~		--exclude=TAGS		\
	--exclude=config.log	--exclude=config.status	\
	--exclude=config.cache	--exclude=Makefile	\
	--exclude=autom4te.cache	--exclude="{arch}"	\
	--exclude=.arch-ids		--exclude=\+\+\*	\
	--exclude=\=\*					\
	. |							\
	mbfl_program_exec ${TAR} --directory="${distdir}/${pkgdir}" --extract --file=-

    mbfl_program_exec cd "${distdir}"
    mbfl_program_exec ${TAR} --create ${TAR_FLAGS} \
	--file="${archdir}/${archive}" "${pkgdir}"
    mbfl_program_exec ${RM} --force --recursive "${distdir}"
    mbfl_program_exec cd -
    return 0
}
#PAGE
function script_action_bindist () {
    local section="${option_SECTION}"

    if test -z "${section}"; then
	for option_SECTION in bin dev doc sta; do
	    bindist
	done
    else
	bindist
    fi
}
function bindist () {
    local section="${option_SECTION}"
    local package="${option_PACKAGE}"
    local version="${option_VERSION}"
    local top_srcdir="${option_TOP_SRCDIR}"
    local builddir="${option_BUILDDIR}"
    local archdir="${option_ARCHDIR}"
    local archive=
    local makefile="${builddir}/Makefile"
    local distdir=
    local pkgdir=
    local pwd="${PWD}"

    local MKDIR=$(type -path mkdir)
    local MKDIR_FLAGS="--parents --mode=0700"
    local TAR=$(type -path tar)
    local TAR_FLAGS=
    local RM=$(type -path rm)
    local MAKE=$(type -path make)
    local GZIP=$(type -path gzip)
    local BZIP2=$(type -path bzip2)


    # Test preconditions.

    if test -z "${package}"; then
	mbfl_message_error "null package, use --package"
	return 1
    fi

    if test -z "${version}"; then
	mbfl_message_error "null version, use --version"
	return 1
    fi

    if ! TMPDIR=$(mbfl_file_find_tmpdir "${option_TMPDIR}")
	then return 1
    fi

    if ! mbfl_program_check "${MKDIR}" "${TAR}" "${RM}" "${MAKE}"
	then return 1
    fi

    if test ! -f "${makefile}";	then
	mbfl_message_error "unexistent Makefile (${makefile})"
	return 1
    fi

    if test ! -d "${archdir}"; then
	mbfl_message_error "unexistent destination directory (${archdir})"
	return 1
    fi


    # Build the name of the  source archive. Check also the availability
    # of the compressor program: we need it to allow "tar" to unpack the
    # archive.

    archive="${package}_${version}_${section}.tar"
    case "${option_COMPRESS}" in
	gzip)
	    mbfl_program_check "${GZIP}" || return 1
	    TAR_FLAGS="--gzip"
	    archive="${archive}.gz"
	    ;;
	bzip)
	    mbfl_program_check "${BZIP2}" || return 1
	    TAR_FLAGS="--bzip2"
	    archive="${archive}.bz2"
	    ;;
    esac


    # Create the archive.

    distdir="${TMPDIR}/dist"
    pkgdir="${package}_${version}"

    mbfl_message_verbose "building distribution archive ${section} section\n"
    mbfl_message_verbose "makefile: ${makefile}\n"
    mbfl_message_verbose "archive: ${archive}\n"
    mbfl_message_verbose "temporary directory: ${distdir}\n"
    mbfl_message_verbose "archive in: ${archdir}\n"

    mbfl_program_exec ${MKDIR} ${MKDIR_FLAGS} "${distdir}/${pkgdir}"

    mbfl_program_exec ${MAKE} -q ${section}-install
    if test $? = 0; then
	mbfl_message_warning "no ${section}-install rule (not an error)"
	return 0
    else
	cd "${builddir}" && mbfl_program_exec ${MAKE} ${section}-install \
	    INSTALL_ROOT="${distdir}/${pkgdir}"
	if test $? != 0; then
	    mbfl_message_warning "no ${section}-install rule (not an error)"
	    return 0
	fi
    fi

    mbfl_program_exec cd "${distdir}/${pkgdir}"
    mbfl_program_exec ${TAR} --create ${TAR_FLAGS} --file="${archdir}/${archive}" .
    mbfl_program_exec ${RM} --force --recursive "${distdir}"
    mbfl_program_exec cd -
    return 0
}
#PAGE
function script_action_debian () {
    local section="${option_SECTION}"

    if test -z "${section}"; then
	for option_SECTION in bin dev doc sta; do
	    debian
	done
    else
	debian
    fi
}
function debian () {
    local section="${option_SECTION}"
    local package="${option_PACKAGE}"
    local version="${option_VERSION}"
    local top_srcdir="${option_TOP_SRCDIR}"
    local top_builddir="${option_TOP_BUILDDIR}"
    local archdir="${option_ARCHDIR}"
    local archive=
    local distdir=
    local pkgdir=

    local MKDIR="${program_MKDIR} --parents --mode=0700"
    local TAR="${program_TAR}"
    local TAR_FLAGS=
    local RM="${program_RM}"
    local INSTALL="${program_INSTALL}"
    local DPKG="$(type -path dpkg)"
    local GZIP=$(type -path gzip)
    local BZIP2=$(type -path bzip2)

    local dummy= tmp=


    # Preconditions.

    if test -z "${package}"
	then
	mbfl_message_error "null package, use --package"
	return 1
    fi

    if test -z "${version}"
	then
	mbfl_message_error "null version, use --version"
	return 1
    fi

    if ! TMPDIR=$(mbfl_file_find_tmpdir "${option_TMPDIR}")
	then return 1
    fi

    if ! mbfl_program_check \
		"${program_MKDIR}" "${program_TAR}" "${program_RM}" \
		"${DPKG}" "${program_INSTALL}"
	then return 1
    fi

    if test ! -d "${archdir}"; then
	mbfl_message_error "unexistent destination directory for deb files"
	return 1
    fi

    
    # Find Debian meta  files. If the directory is  not found: we assume
    # that  the  package  does  not  create  the  corresponding  section
    # distribution   (example:  no   "dev"  meta   files  ->   no  "dev"
    # sub-package), so  we print  a warning and  return zero  instead of
    # printing an error and returning one.

    for tmp in 1; do
	for srcdebdir in \
	    "${top_srcdir}/meta/debian/${section}" \
	    "${top_srcdir}/debian/${section}" \
	    "${top_srcdir}/src/meta/debian/${section}"
	  do
	  if test -d "${srcdebdir}" -a -f "${srcdebdir}/control.in"
	      then
	      break 2
	  fi
	done
	mbfl_message_warning "unable to locate source debian meta files, ${section} section"
	return 0
    done

    for tmp in 1; do
	for blddebdir in \
	    "${top_builddir}/meta/debian/${section}" \
	    "${top_builddir}/debian/${section}"
	  do
	  if test -d "${blddebdir}" -a -f "${blddebdir}/control"
	      then
	      break 2
	  fi
	done
	mbfl_message_warning "unable to locate build debian meta files, ${section} section (possibly not an error)"
	return 0
    done


    # Build the name of the  source archive. Check also the availability
    # of the compressor program: we need it to allow "tar" to unpack the
    # archive.

    archive=
    case "${section}" in
	bin|dev|doc|sta)
	    archive="${package}_${version}_${section}.tar"
	    ;;
    esac

    case "${option_COMPRESS}" in
	gzip)
	    mbfl_program_check "${GZIP}" || return 1
	    TAR_FLAGS="--gzip"
	    archive="${archive}.gz"
	    ;;
	bzip)
	    mbfl_program_check "${BZIP2}" || return 1
	    TAR_FLAGS="--bzip2"
	    archive="${archive}.bz2"
	    ;;
    esac

    if test ! -f "${archive}"
	then
	mbfl_message_error "unexistent archive file (${archive})"
	return 1
    fi


    # Build package.

    distdir="${TMPDIR}/dist"
    pkgdir="${package}_${version}"

    mbfl_message_verbose "building debian archive\n"
    mbfl_message_verbose "source file: ${file}\n"
    mbfl_message_verbose "temporary directory: ${distdir}\n"
    mbfl_message_verbose "archive in: ${archdir}\n"


    mbfl_program_exec ${MKDIR} "${distdir}/${pkgdir}"

    mbfl_program_exec ${TAR} --directory="${distdir}/${pkgdir}" \
	--extract --no-same-owner ${TAR_FLAGS} --file="${archive}"
    
    mbfl_program_exec ${INSTALL} -m 0755 -d "${distdir}/${pkgdir}/DEBIAN"
    mbfl_program_exec \
	${INSTALL} -m 0444 "${blddebdir}/control" "${distdir}/${pkgdir}/DEBIAN"
    for tmp in preinst postinst prerm postrm; do
      if test -f "${srcdebdir}/${tmp}"; then
	  mbfl_program_exec \
	      ${INSTALL} -m 0555 "${srcdebdir}/${tmp}" "${distdir}/${pkgdir}/DEBIAN"
      fi
    done

    mbfl_program_exec ${DPKG} --build "${distdir}/${pkgdir}" "${archdir}"
    mbfl_program_exec ${RM} --force --recursive "${distdir}"
    return 0
}
#PAGE
## ------------------------------------------------------------
## Main script.
## ------------------------------------------------------------

mbfl_main

### end of file
# Local Variables:
# mode: sh
# page-delimiter: "^#PAGE$"
# End:
