# tests.tcl --
# 
# Part of: ZTcl
# Contents: tests for the compress procedures
# Date: Sat Jul  5, 2003
# 
# Abstract
# 
# 
# 
# Copyright (c) 2003, 2004 Marco Maggi
# 
# The author  hereby grant permission to use,  copy, modify, distribute,
# and  license this  software  and its  documentation  for any  purpose,
# provided that  existing copyright notices  are retained in  all copies
# and that  this notice  is included verbatim  in any  distributions. No
# written agreement, license, or royalty  fee is required for any of the
# authorized uses.  Modifications to this software may be copyrighted by
# their authors and need not  follow the licensing terms described here,
# provided that the new terms are clearly indicated on the first page of
# each file where they apply.
# 
# IN NO  EVENT SHALL THE AUTHOR  OR DISTRIBUTORS BE LIABLE  TO ANY PARTY
# FOR  DIRECT, INDIRECT, SPECIAL,  INCIDENTAL, OR  CONSEQUENTIAL DAMAGES
# ARISING OUT  OF THE  USE OF THIS  SOFTWARE, ITS DOCUMENTATION,  OR ANY
# DERIVATIVES  THEREOF, EVEN  IF THE  AUTHOR  HAVE BEEN  ADVISED OF  THE
# POSSIBILITY OF SUCH DAMAGE.
# 
# THE  AUTHOR  AND DISTRIBUTORS  SPECIFICALLY  DISCLAIM ANY  WARRANTIES,
# INCLUDING,   BUT   NOT  LIMITED   TO,   THE   IMPLIED  WARRANTIES   OF
# MERCHANTABILITY,    FITNESS   FOR    A    PARTICULAR   PURPOSE,    AND
# NON-INFRINGEMENT.  THIS  SOFTWARE IS PROVIDED  ON AN "AS  IS" BASIS,
# AND  THE  AUTHOR  AND  DISTRIBUTORS  HAVE  NO  OBLIGATION  TO  PROVIDE
# MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
# 

#PAGE
## ------------------------------------------------------------
## Test namespace.
## ------------------------------------------------------------

namespace eval test {

    proc get_this_library { libname } {
	set id [open $libname {RDONLY}]
	fconfigure $id -encoding binary -translation binary
	set data [read $id]
	close $id
	return $data
    }

    variable	proofgz	[file join [::tcltest::configure -testdir] proof.gz]
    variable	libname [file join [::tcltest::configure -testdir] .. $::libfile]

    variable	data	"abcdefghilmnopqrstuvz"
    variable	data1	[::tcltest::viewFile [info script]]
    variable	data2	[get_this_library [file join $env(builddir) $::libfile]]

    proc open_write_close { fileName data } {
	variable	zlib

	set id [$zlib open $fileName WRONLY]
	fconfigure $id -translation binary -encoding binary
	puts -nonewline $id $data
	close $id
    }

    proc open_read_close { fileName size varName } {
	variable	zlib
	upvar	$varName unzipped
	
	set id [$zlib open $fileName RDONLY]
	fconfigure $id -translation binary -encoding binary
	if { $size > 0 } {
	    set unzipped [read $id $size]
	} else {
	    set unzipped [read $id]
	}
	close $id
    }

#PAGE

::tcltest::test compress-1.1 "compress a string" {
    -body	{
	catch {$zlib compress $data}
    }
    -result 0
}

::tcltest::test compress-1.2 "compress and decompress a string" {
    -body	{
	set size	[string length $data]
	set zipped	[$zlib compress $data]
	set unzipped	[$zlib decompress $zipped -size $size]
	string equal $data $unzipped
    }
    -result 1
    -cleanup	{
	unset -nocomplain unzipped zipped
    }
}

::tcltest::test compress-1.3 "compress and decompress with options" {
    -body	{
	set size	[string length $data]
	set zipped	[$zlib compress $data -level 5]
	set unzipped	[$zlib decompress $zipped -size $size]
	string equal $data $unzipped
    }
    -result 1
    -cleanup	{
	unset -nocomplain unzipped zipped
    }
}

::tcltest::test compress-1.4 "compress and decompress with default options" {
    -body	{
	set size	[string length $data]
	set zipped	[$zlib compress $data -level default]
	set unzipped	[$zlib decompress $zipped -size $size]
	string equal $data $unzipped
    }
    -result 1
    -cleanup	{
	unset -nocomplain unzipped zipped
    }
}

::tcltest::test compress-1.5 "compress and decompress a string with no size" {
    -body	{
	set zipped	[$zlib compress $data]
	set unzipped	[$zlib decompress $zipped]
	string equal $data $unzipped
    }
    -result 1
    -cleanup	{
	unset -nocomplain unzipped zipped
    }
}

::tcltest::test compress-1.6 "compress the empty string" {
    -body	{
	$zlib compress {}
    }
    -result {}
}

::tcltest::test compress-1.7 "decompress the empty string" {
    -body	{
	$zlib decompress {}
    }
    -result {}
}

#PAGE

::tcltest::test compress-2.1 "compress this test file" {
    -body	{
	catch {$zlib compress $data1}
    }
    -result 0
}

::tcltest::test compress-2.2 "compress and decompress this test file" {
    -body	{
	set size	[string length $data1]
	set zipped	[$zlib compress $data1]
	set unzipped	[$zlib decompress $zipped -size $size]
	string equal $data1 $unzipped
    }
    -result 1
    -cleanup	{
	unset -nocomplain unzipped zipped
    }
}

::tcltest::test compress-2.3 "comp/decomp this test file with no size" {
    -body	{
	set zipped	[$zlib compress $data1]
	set unzipped	[$zlib decompress $zipped]
	string equal $data1 $unzipped
    }
    -result 1
    -cleanup	{
	unset -nocomplain unzipped zipped
    }
}

#PAGE

::tcltest::test compress-3.1 "compress the ztcl library" {
    -body	{
	catch {$zlib compress $data2}
    }
    -result 0
}

::tcltest::test compress-3.2 "compress and decompress the ztcl library" {
    -body	{
	set size	[string length $data2]
	set zipped	[$zlib compress $data2]
	set unzipped	[$zlib decompress $zipped -size $size]

	expr {
	    ([string length $data2] == $size)
	    && [string equal $data2 $unzipped]
	}
    }
    -result 1
    -cleanup	{
	unset -nocomplain unzipped zipped
    }
}

::tcltest::test compress-3.3 "comp/decomp this library with no size" {
    -body	{
	set zipped	[$zlib compress $data2]
	set unzipped	[$zlib decompress $zipped]
	string equal $data2 $unzipped
    }
    -result 1
    -cleanup	{
	unset -nocomplain unzipped zipped
    }
}

#PAGE

::tcltest::test gzfile-1.1 "comp/decomp a string in a file" {
    -body {
	open_write_close $proofgz $data
	open_read_close  $proofgz [string length $data] unzipped
	string equal $data $unzipped
    }
    -result 1
    -cleanup	{
	::tcltest::removeFile $proofgz
	unset -nocomplain id unzipped
    }
}

::tcltest::test gzfile-1.2 "comp/decomp a string in a file with no size" {
    -body {
	open_write_close $proofgz $data
	open_read_close  $proofgz 0 unzipped
	string equal $data $unzipped
    }
    -result 1
    -cleanup	{
	::tcltest::removeFile $proofgz
	unset -nocomplain id unzipped
    }
}

#PAGE

::tcltest::test gzfile-2.1 "compress this test file" {
    -body {
	open_write_close $proofgz $data1
	open_read_close  $proofgz [string length $data1] unzipped
	string equal $data1 $unzipped
    }
    -result 1
    -cleanup	{
	::tcltest::removeFile $proofgz
	unset -nocomplain id unzipped
    }
}

::tcltest::test gzfile-2.2 "compress this test file, no size" {
    -body {
	open_write_close $proofgz $data1
	open_read_close  $proofgz 0 unzipped
	string equal $data1 $unzipped
    }
    -result 1
    -cleanup	{
	::tcltest::removeFile $proofgz
	unset -nocomplain id unzipped
    }
}

::tcltest::test gzfile-2.3 "comp/decomp this test file" {
    -body	{
	open_write_close $proofgz $data1

	set id [$zlib open $proofgz RDONLY]
	fconfigure $id -translation binary -encoding binary
	while { ! [eof $id] } {
	    append unzipped [read $id 10]
	}
	close $id

	string equal $data1 $unzipped
    }
    -result 1
    -cleanup	{
	::tcltest::removeFile $proofgz
	unset -nocomplain id unzipped
    }
}

::tcltest::test gzfile-3.1 "compress this library" {
    -body {
	open_write_close $proofgz $data2
	open_read_close  $proofgz [string length $data2] unzipped
	string equal $data2 $unzipped
    }
    -result 1
    -cleanup	{
	::tcltest::removeFile $proofgz
	unset -nocomplain id unzipped
    }
}

::tcltest::test gzfile-3.2 "compress and decompress this library" {
    -body	{
	open_write_close $proofgz $data2

	set id [$zlib open $proofgz RDONLY]
	fconfigure $id -translation binary -encoding binary
	while { ![eof $id] } {
	    append unzipped [read $id 1024]
	}
	close $id

	string equal $data2 $unzipped
    }
    -result 1
    -cleanup	{
	::tcltest::removeFile $proofgz
	unset -nocomplain id unzipped
    }
}

::tcltest::test gzfile-3.3 "comp/decomp this library with no size" {
    -body	{
	open_write_close $proofgz $data2
	open_read_close  $proofgz [string length $data2] unzipped
	string equal $data2 $unzipped
    }
    -result 1
    -cleanup	{
	::tcltest::removeFile $proofgz
	unset -nocomplain id unzipped
    }
}

#PAGE

::tcltest::test gzfile-4.1 "comp/decom this library with options" {
    -body	{
	set id [$zlib open $proofgz WRONLY]
	fconfigure $id -level 5 -strategy huffman \
	    -encoding binary -translation binary
	puts -nonewline $id $data2
	close $id

	set id [$zlib open $proofgz RDONLY]
	fconfigure $id -translation binary -encoding binary
	while { ! [eof $id] } {
	    append unzipped [read $id 1024]
	}
	close $id

	string equal $data2 $unzipped
    }
    -result 1
    -cleanup	{
	::tcltest::removeFile $proofgz
	unset -nocomplain id unzipped
    }
}

::tcltest::test gzfile-4.2 "comp/decom this library with default options" {
    -body	{
	set id [$zlib open $proofgz WRONLY]
	fconfigure $id -level default -strategy default \
	    -encoding binary -translation binary
	puts -nonewline $id $data2
	close $id

	set id [$zlib open $proofgz RDONLY]
	fconfigure $id -translation binary -encoding binary
	while { ! [eof $id] } {
	    append unzipped [read $id 1024]
	}
	close $id

	string equal $data2 $unzipped
    }
    -result 1
    -cleanup	{
	::tcltest::removeFile $proofgz
	unset -nocomplain id unzipped
    }
}

::tcltest::test gzfile-4.3 "comp/decom this library with default options" {
    -body	{
	set id [$zlib open $proofgz WRONLY]
	fconfigure $id -level default -strategy rle \
	    -encoding binary -translation binary
	puts -nonewline $id $data2
	close $id

	set id [$zlib open $proofgz RDONLY]
	fconfigure $id -translation binary -encoding binary
	while { ! [eof $id] } {
	    append unzipped [read $id 1024]
	}
	close $id

	string equal $data2 $unzipped
    }
    -result 1
    -cleanup	{
	::tcltest::removeFile $proofgz
	unset -nocomplain id unzipped
    }
}

#PAGE

::tcltest::test gzfile-5.1 "compress compatibility with zip" {
    -constraints {[string length [auto_execok gunzip]] != 0}
    -body	{
	set id [$zlib open $proofgz WRONLY]
	fconfigure $id -translation binary -encoding binary
	puts -nonewline  $id $data2
	close $id

	set id [open "|gunzip --stdout $proofgz" RDONLY]
	fconfigure $id -translation binary -encoding binary
	set unzipped [read $id]
	close $id

	string equal $data2 $unzipped
    }
    -result 1
    -cleanup	{
	::tcltest::removeFile $proofgz
	unset -nocomplain id unzipped
    }
}

::tcltest::test gzfile-5.2 "decompress compatibility with zip" {
    -constraints {[string length [auto_execok gzip]] != 0}
    -body	{
	exec gzip --stdout $libname >$proofgz

	set id [$zlib open $proofgz RDONLY]
	fconfigure $id -translation binary -encoding binary
	set unzipped [read $id]
	close $id

	string equal $data2 $unzipped
    }
    -result 1
    -cleanup	{
	::tcltest::removeFile $proofgz
	unset -nocomplain id unzipped
    }
}

#PAGE

::tcltest::test error-1.1 "main command, wrong num args" {
    -body	{
	catch { $zlib } res
	list $res $errorCode 
    }
    -result "{wrong # args: should be \"$zlib subcommand ?arg ...?\"} LOGIC"
}

::tcltest::test error-1.2 "main command, unknown subcommand" {
    -body	{
	catch { $zlib gasp } res
	list $res $errorCode
    }
    -result { {bad subcommand "gasp": *} LOGIC }
    -match glob
}

#PAGE

::tcltest::test error-2.1 "compress subcommand, wrong num args" {
    -body	{
	catch { $zlib compress } res
	list $res $errorCode
    }
    -result "{wrong # args: should be \"$zlib compress data ?options?\"} LOGIC"
}

::tcltest::test error-2.2 "compress subcommand, wrong option" {
    -body	{
	catch { $zlib compress $data -gulp } res
	list $res $errorCode
    }
    -result { {bad option "-gulp": *} LOGIC }
    -match	glob
}

::tcltest::test error-2.3 "compress subcommand, -level without argument" {
    -body	{
	catch { $zlib compress $data -level } res
	list $res $errorCode
    }
    -result { {option "-level" requires argument} LOGIC }
}

::tcltest::test error-2.4 "compress subcommand, -level invalid value" {
    -body	{
	catch { $zlib compress $data -level gasp } res
	list $res $errorCode
    }
    -result { {wrong compression level "gasp"} LOGIC }
}

::tcltest::test error-2.5 "compress subcommand, -level invalid value" {
    -body	{
	catch { $zlib compress $data -level 123 } res
	list $res $errorCode
    }
    -result { {wrong compression level "123"} LOGIC }
}

#PAGE

::tcltest::test error-3.1 "decompress subcommand, wrong num args" {
    -body	{
	catch { $zlib decompress } res
	list $res $errorCode
    }
    -result "{wrong # args: should be \"$zlib decompress data ?options?\"} LOGIC"
}

::tcltest::test error-3.2 "decompress subcommand, wrong num args" {
    -body	{
	catch { $zlib decompress one -gulp} res
	list $res $errorCode
    }
    -result {{bad option "-gulp": *} LOGIC}
    -match	glob
}

::tcltest::test error-3.3 "decompress subcommand, invalid argument" {
    -body	{
	catch { $zlib decompress $data -size gulp } res
	list $res $errorCode
    }
    -result { {expected unsigned but got "gulp"} LOGIC }
    -match	glob
}

#PAGE

::tcltest::test error-4.1 "open subcommand, wrong num args" {
    -body	{
	catch { $zlib open } res
	list $res $errorCode
    }
    -result "{wrong # args: should be \"$zlib open file mode\"} LOGIC"
}

::tcltest::test error-4.2 "open subcommand, wrong num args" {
    -body	{
	catch { $zlib open cip } res
	list $res $errorCode
    }
    -result "{wrong # args: should be \"$zlib open file mode\"} LOGIC"
}

#PAGE

::tcltest::test info-1.1 "version of ZLib" {
    -body	{
	regexp -- {^[0-9]+\.[0-9]+\.[0-9]+} [$zlib info version]
    }
    -result 1
}

#PAGE

::tcltest::test info-3.1 "info compression level" {
    -body	{
	set id [$zlib open $proofgz WRONLY]
	fconfigure $id -level 8
	set res [fconfigure $id -level]
	close $id
	set res
    }
    -result 8
    -cleanup {
	::tcltest::removeFile $proofgz
	unset -nocomplain id res
    }
}

::tcltest::test info-3.2 "info compression level" {
    -body	{
	set id [$zlib open $proofgz WRONLY]
	fconfigure $id -level default
	set res [fconfigure $id -level]
	close $id
	set res
    }
    -result 6
    -cleanup {
	::tcltest::removeFile $proofgz
	unset -nocomplain id res
    }
}

::tcltest::test info-3.3 "info compression level" {
    -body	{
	set id [$zlib open $proofgz WRONLY]
	fconfigure $id -level best
	set res [fconfigure $id -level]
	close $id
	set res
    }
    -result 9
    -cleanup {
	::tcltest::removeFile $proofgz
	unset -nocomplain id res
    }
}

::tcltest::test info-3.4 "info compression level" {
    -body	{
	set id [$zlib open $proofgz WRONLY]
	fconfigure $id -level fast
	set res [fconfigure $id -level]
	close $id
	set res
    }
    -result 1
    -cleanup {
	::tcltest::removeFile $proofgz
	unset -nocomplain id res
    }
}

#PAGE

::tcltest::test info-4.2 "info compression strategy" {
    -body	{
	set id [$zlib open $proofgz WRONLY]
	fconfigure $id -strategy default
	set res [fconfigure $id -strategy]
	close $id
	set res
    }
    -result default
    -cleanup {
	::tcltest::removeFile $proofgz
	unset -nocomplain id res
    }
}

::tcltest::test info-4.3 "info compression strategy" {
    -body	{
	set id [$zlib open $proofgz WRONLY]
	fconfigure $id -strategy huffman
	set res [fconfigure $id -strategy]
	close $id
	set res
    }
    -result huffman
    -cleanup {
	::tcltest::removeFile $proofgz
	unset -nocomplain id res
    }
}

::tcltest::test info-4.4 "info compression strategy" {
    -body	{
	set id [$zlib open $proofgz WRONLY]
	fconfigure $id -strategy filtered
	set res [fconfigure $id -strategy]
	close $id
	set res
    }
    -result filtered
    -cleanup {
	::tcltest::removeFile $proofgz
	unset -nocomplain id res
    }
}

::tcltest::test info-4.5 "info compression strategy" {
    -body	{
	set id [$zlib open $proofgz WRONLY]
	fconfigure $id -strategy rle
	set res [fconfigure $id -strategy]
	close $id
	set res
    }
    -result rle
    -cleanup {
	::tcltest::removeFile $proofgz
	unset -nocomplain id res
    }
}
#PAGE

::tcltest::test info-5.1 "is strategy" {
    -body	{
	$zlib info isstrategy default
    }
    -result 1
}

::tcltest::test info-5.2 "is strategy" {
    -body	{
	$zlib info isstrategy huffman
    }
    -result 1
}

::tcltest::test info-5.3 "is strategy" {
    -body	{
	$zlib info isstrategy filtered
    }
    -result 1
}

::tcltest::test info-5.4 "is strategy" {
    -body	{
	$zlib info isstrategy gulp
    }
    -result 0
}

::tcltest::test info-5.5 "is strategy" {
    -body	{
	$zlib info isstrategy rle
    }
    -result 1
}

#PAGE

::tcltest::test info-6.1 "is level" {
    -body	{
	$zlib info islevel 1
    }
    -result 1
}

::tcltest::test info-6.2 "is level" {
    -body	{
	$zlib info islevel 5
    }
    -result 1
}

::tcltest::test info-6.3 "is level" {
    -body	{
	$zlib info islevel 9
    }
    -result 1
}

::tcltest::test info-6.4 "is level" {
    -body	{
	$zlib info islevel best
    }
    -result 1
}

::tcltest::test info-6.5 "is level" {
    -body	{
	$zlib info islevel fast
    }
    -result 1
}

::tcltest::test info-6.7 "is level" {
    -body	{
	$zlib info islevel default
    }
    -result 1
}

::tcltest::test info-6.8 "is level" {
    -body	{
	$zlib info islevel 0
    }
    -result 1
}

::tcltest::test info-6.9 "is level" {
    -body	{
	$zlib info islevel 10
    }
    -result 0
}

::tcltest::test info-6.10 "is level" {
    -body	{
	$zlib info islevel -1
    }
    -result 0
}

#PAGE
## ------------------------------------------------------------
## End of test namespace.
## ------------------------------------------------------------

::tcltest::cleanupTests
}


### end of file
# Local Variables:
# mode: tcl
# page-delimiter: "^#PAGE"
# End:
