/*  test-1.1.c --
   
   Part of: zlib tests
   Contents: buffer reallocation size tests
   Date: Wed May 19, 2004
   
   Abstract
   
	Tests algorithms to compute the reallocation size of a buffer.
   
   Copyright (c) 2004 Marco Maggi
   
   The author  hereby grant permission to use,  copy, modify, distribute,
   and  license this  software  and its  documentation  for any  purpose,
   provided that  existing copyright notices  are retained in  all copies
   and that  this notice  is included verbatim  in any  distributions. No
   written agreement, license, or royalty  fee is required for any of the
   authorized uses.  Modifications to this software may be copyrighted by
   their authors and need not  follow the licensing terms described here,
   provided that the new terms are clearly indicated on the first page of
   each file where they apply.
   
   IN NO  EVENT SHALL THE AUTHOR  OR DISTRIBUTORS BE LIABLE  TO ANY PARTY
   FOR  DIRECT, INDIRECT, SPECIAL,  INCIDENTAL, OR  CONSEQUENTIAL DAMAGES
   ARISING OUT  OF THE  USE OF THIS  SOFTWARE, ITS DOCUMENTATION,  OR ANY
   DERIVATIVES  THEREOF, EVEN  IF THE  AUTHOR  HAVE BEEN  ADVISED OF  THE
   POSSIBILITY OF SUCH DAMAGE.
   
   THE  AUTHOR  AND DISTRIBUTORS  SPECIFICALLY  DISCLAIM ANY  WARRANTIES,
   INCLUDING,   BUT   NOT  LIMITED   TO,   THE   IMPLIED  WARRANTIES   OF
   MERCHANTABILITY,    FITNESS   FOR    A    PARTICULAR   PURPOSE,    AND
   NON-INFRINGEMENT.  THIS  SOFTWARE IS PROVIDED  ON AN "AS  IS" BASIS,
   AND  THE  AUTHOR  AND  DISTRIBUTORS  HAVE  NO  OBLIGATION  TO  PROVIDE
   MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
   
*/

#include "test.h"

void	test (uLongf delta);
uLongf	max_size = 0;
const char *presentation = "\n\
Test to avoid \"uLongf\" overflow when computing the new\n\
size of a buffer by incrementing the old size:\n\
\n\
\tsize += delta;\n\
\n\
before incrementing we test that:\n\
\n\
\tmax_size - delta <= size\n\
\n\
where \"max_size\" holds the maximum number representable by\n\
a \"uLongf\"; if the test is true it is safe to add \"delta\"\n\
to \"size\".\n\
\n\
It is easy to compute \"max_size\":\n\
\n\
\tuLongf   max_size = 0;\n\
\n\
\tmax_size  = ~max_size;\n\
\n\
On this platform: the number of bytes in a \"uLongf\" is %d; the\n\
maximum value of a \"uLongf\" is:\n\
\n\
\t%lu\n\
\n\
ULONG_MAX is:\n\
\n\
\t%lu\n\
\n\
and UINT_MAX is:\n\
\n\
\t%u\n";

int
main (int argc, const char *const argv[])
{
  max_size  = ~max_size;

  printf(presentation, sizeof(uLongf), max_size, ULONG_MAX, UINT_MAX);

  test(1);
  test(16);
  exit(EXIT_SUCCESS);
}
void
test (uLongf delta)
{
  uLongf	size = max_size - delta * 4 - 3;


  printf("\n\nTesting with delta=%lu\n\n", delta);
  printf("initial size:\t%lu\n", size);
  printf("delta size:\t%lu\n", delta);

  while (max_size - delta >= size)
    {
      size += delta;
      printf("new size:\t%lu\t(max size - size): %lu\n",
	     size, max_size - size);
    }
  printf("stop at size:\t%lu\n", size);
}

/* end of file */
