/* test-2.1.c --
   
   Part of: zlib tests
   Contents: compress/uncompress functions
   Date: Wed May 19, 2004
   
   Abstract
   
	
   
   Copyright (c) 2004 Marco Maggi
   
   The author  hereby grant permission to use,  copy, modify, distribute,
   and  license this  software  and its  documentation  for any  purpose,
   provided that  existing copyright notices  are retained in  all copies
   and that  this notice  is included verbatim  in any  distributions. No
   written agreement, license, or royalty  fee is required for any of the
   authorized uses.  Modifications to this software may be copyrighted by
   their authors and need not  follow the licensing terms described here,
   provided that the new terms are clearly indicated on the first page of
   each file where they apply.
   
   IN NO  EVENT SHALL THE AUTHOR  OR DISTRIBUTORS BE LIABLE  TO ANY PARTY
   FOR  DIRECT, INDIRECT, SPECIAL,  INCIDENTAL, OR  CONSEQUENTIAL DAMAGES
   ARISING OUT  OF THE  USE OF THIS  SOFTWARE, ITS DOCUMENTATION,  OR ANY
   DERIVATIVES  THEREOF, EVEN  IF THE  AUTHOR  HAVE BEEN  ADVISED OF  THE
   POSSIBILITY OF SUCH DAMAGE.
   
   THE  AUTHOR  AND DISTRIBUTORS  SPECIFICALLY  DISCLAIM ANY  WARRANTIES,
   INCLUDING,   BUT   NOT  LIMITED   TO,   THE   IMPLIED  WARRANTIES   OF
   MERCHANTABILITY,    FITNESS   FOR    A    PARTICULAR   PURPOSE,    AND
   NON-INFRINGEMENT.  THIS  SOFTWARE IS PROVIDED  ON AN "AS  IS" BASIS,
   AND  THE  AUTHOR  AND  DISTRIBUTORS  HAVE  NO  OBLIGATION  TO  PROVIDE
   MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
   
*/

#define SOURCE_SIZE             4096*32
#define INITIAL_DEST_SIZE       512
#define DELTA			256

#include "test.h"

const char * description = "\n\
Testing the \"%s()\" function. Input buffer size: %lu;\n\
initial output buffer size: %lu; output buffer\n\
reallocation increment: %lu.\n\n";

typedef struct CompressStuff {
  Bytef * 	srcPtr;
  Bytef * 	dstPtr;
  uLongf	srcLen;
  uLongf	dstLen;
  uLongf	delta;
  uLongf	max_size;
} CompressStuff;

void
cs_init (CompressStuff *frame)
{
  uLongf	max_size = 0;


  max_size  = ~max_size;

  frame->srcLen		= SOURCE_SIZE;
  frame->dstLen		= INITIAL_DEST_SIZE;
  frame->delta		= DELTA;
  frame->max_size	= max_size;
}


int
main (int argc, const char *const argv[])
{
  Bytef 	original[SOURCE_SIZE];
  CompressStuff	frame;
  int		result;


  fprintf(stderr, description, "compress", srcLen, dstLen, delta);

  frame->srcPtr = original;
  fill_buffer(frame->srcLen, frame->srcPtr);
  dstPtr = (Bytef *) malloc(dstLen);
  assert(dstPtr);

  /* Compress. */

  result = Z_OK;
  do
    {
      realloc_buffer(result, &dstLen, &dstPtr, delta);
      result = compress(dstPtr, &dstLen, srcPtr, srcLen);      
    }
  while (Z_BUF_ERROR == result);

  if (Z_OK != result) { handle_error(result); }

  dstPtr = realloc(dstPtr, dstLen);
  fprintf(stderr, "Compressed output size: %lu.\n", dstLen);

  /* Prepare input for decompression. */

  srcLen = dstLen;
  srcPtr = (Bytef *) malloc(srcLen);
  assert(srcPtr);
  memcpy(srcPtr, dstPtr, srcLen);

  dstLen = INITIAL_DEST_SIZE;
  free(dstPtr);
  dstPtr = (Bytef *) malloc(dstLen);
  assert(dstPtr);

  delta = 4096*8;

  /* Decompress. */

  fprintf(stderr, description, "uncompress", srcLen, dstLen, delta);
  result = Z_OK;
  do
    {
      realloc_buffer(result, &dstLen, &dstPtr, delta);
      result = uncompress(dstPtr, &dstLen, srcPtr, srcLen);      
    }
  while (Z_BUF_ERROR == result);

  if (Z_OK != result) { handle_error(result); }

  fprintf(stderr, "Decompressed output size: %lu.\n", dstLen);

  fprintf(stderr, "Identity check: ");
  if (memcmp(original, dstPtr, dstLen) != 0)
    {
      fprintf(stderr, "bad\n");
      exit(EXIT_SUCCESS);
    }

  fprintf(stderr, "good\n");  
  free(dstPtr);
  exit(EXIT_SUCCESS);
}

/* end of file */
