/*  test.h --
   
   Part of: zlib tests
   Contents: header file for tests
   Date: Wed May 19, 2004
   
   Abstract
   
   
   
   Copyright (c) 2004 Marco Maggi
   
   The author  hereby grant permission to use,  copy, modify, distribute,
   and  license this  software  and its  documentation  for any  purpose,
   provided that  existing copyright notices  are retained in  all copies
   and that  this notice  is included verbatim  in any  distributions. No
   written agreement, license, or royalty  fee is required for any of the
   authorized uses.  Modifications to this software may be copyrighted by
   their authors and need not  follow the licensing terms described here,
   provided that the new terms are clearly indicated on the first page of
   each file where they apply.
   
   IN NO  EVENT SHALL THE AUTHOR  OR DISTRIBUTORS BE LIABLE  TO ANY PARTY
   FOR  DIRECT, INDIRECT, SPECIAL,  INCIDENTAL, OR  CONSEQUENTIAL DAMAGES
   ARISING OUT  OF THE  USE OF THIS  SOFTWARE, ITS DOCUMENTATION,  OR ANY
   DERIVATIVES  THEREOF, EVEN  IF THE  AUTHOR  HAVE BEEN  ADVISED OF  THE
   POSSIBILITY OF SUCH DAMAGE.
   
   THE  AUTHOR  AND DISTRIBUTORS  SPECIFICALLY  DISCLAIM ANY  WARRANTIES,
   INCLUDING,   BUT   NOT  LIMITED   TO,   THE   IMPLIED  WARRANTIES   OF
   MERCHANTABILITY,    FITNESS   FOR    A    PARTICULAR   PURPOSE,    AND
   NON-INFRINGEMENT.  THIS  SOFTWARE IS PROVIDED  ON AN "AS  IS" BASIS,
   AND  THE  AUTHOR  AND  DISTRIBUTORS  HAVE  NO  OBLIGATION  TO  PROVIDE
   MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
   
*/

#ifndef __TEST_H
#define __TEST_H 1

#include <stdlib.h>
#include <stdio.h>
#include <assert.h>
#include <limits.h>
#include <string.h>

#include <zlib.h>


void
fill_buffer (uLongf srcLen, Bytef *srcPtr)
{
  uLongf	i;
  unsigned char	ch = '\0';

  for (i=0; i<srcLen; srcPtr[++i] = ++ch) ;
}

void
handle_error (int code)
{
  const char *	errorInfo;

  switch (code)
    {
    case Z_MEM_ERROR:
      errorInfo = "not enough memory (Z_MEM_ERROR)";
      break;

    case Z_DATA_ERROR:
      errorInfo = "invalid input data (Z_DATA_ERROR)";
      break;

    case Z_STREAM_ERROR:
      errorInfo = "invalid input parameters (Z_STREAM_ERROR)";
      break;

    case Z_OK:
      errorInfo = "no error (Z_OK)";
      break;

    default:
      errorInfo = "unknown error, but error";
    }

  fprintf(stderr, "Error: %s (%d)\n", errorInfo, code);
  exit(EXIT_FAILURE);
}

void
realloc_buffer (result, dstLenPtr, dstPtrPtr, delta)
     int	result;
     Bytef **	dstPtrPtr;
     uLongf *	dstLenPtr;
     uLongf	delta;
{
  uLongf	max_size;
  Bytef *	dstPtr = *dstPtrPtr;
  uLongf	dstLen = *dstLenPtr;


  if (Z_BUF_ERROR != result)
    {
      return;
    }

  max_size -= max_size;
  max_size  = ~max_size;

  if (max_size - delta >= dstLen)
    {
      dstLen += delta;
      fprintf(stderr, "Not enough, new output buffer size: %lu.\n", dstLen);
    }
  else
    {
      fprintf(stderr, "not enough memory to (re)allocate output buffer");
      exit(EXIT_FAILURE);
    }
  
  dstPtr = (Bytef *) realloc(dstPtr, dstLen);
  if (! dstPtr)
    {
      fprintf(stderr, "error reallocating output buffer");
      exit(EXIT_FAILURE);
    }

  *dstPtrPtr = dstPtr;
  *dstLenPtr = dstLen;
}

#endif /* __TEST_H */

/* end of file */
